
from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.transport.utils import parse_xml_to_dict
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..models import (
    ReleaseIntegrationPackStatus,
    ReleaseIntegrationPackStatusBulkRequest,
    ReleaseIntegrationPackStatusBulkResponse,
)


class ReleaseIntegrationPackStatusService(BaseService):

    @cast_models
    def get_release_integration_pack_status(
        self, id_: str
    ) -> Union[ReleaseIntegrationPackStatus, str]:
        """To retrieve the release status of the publisher integration pack, follow these steps:

        1. Send a POST request to the ReleaseIntegrationPackStatus object. The response will return a requestId.
        2. Use the requestId returned in Step 1 to make a subsequent call to the ReleaseIntegrationPackStatus object to retrieve detailed information about the released integration pack.
        3. Repeatedly poll the ReleaseIntegrationPackStatus object using the requestId until the details of the released integration pack are available. If the request is still in progress or scheduled, it returns an HTTP 202 status code. When the integration pack is released successfully, the ReleaseIntegrationPackStatus object returns the released details.

        :param id_: A unique ID assigned by the system to the integration pack.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ReleaseIntegrationPackStatus, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ReleaseIntegrationPackStatus/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ReleaseIntegrationPackStatus._unmap(response)
        if content == "application/xml":
            return ReleaseIntegrationPackStatus._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def bulk_release_integration_pack_status(
        self, request_body: ReleaseIntegrationPackStatusBulkRequest = None
    ) -> Union[str, ReleaseIntegrationPackStatusBulkResponse]:
        """The bulk GET operation returns multiple objects based on the supplied account IDs, to a maximum of 100. To learn more about `bulk`, refer to [Bulk GET operations](#section/Introduction/Bulk-GET-operations).

        :param request_body: The request body., defaults to None
        :type request_body: ReleaseIntegrationPackStatusBulkRequest, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[str, ReleaseIntegrationPackStatusBulkResponse]
        """

        Validator(ReleaseIntegrationPackStatusBulkRequest).is_optional().validate(
            request_body
        )

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ReleaseIntegrationPackStatus/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/xml":
            return ReleaseIntegrationPackStatusBulkResponse._unmap(parse_xml_to_dict(response))
        if content == "application/json":
            return ReleaseIntegrationPackStatusBulkResponse._unmap(response)
        raise ApiError("Error on deserializing the response.", status, response)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"atom_id": "atomId"})
class AtomPurge(BaseModel):
    """AtomPurge

    :param atom_id: The unique ID assigned by the system to the Runtime cloud attachment. The Runtime ID is found in the user interface by navigating to **Manage \> Runtime Management** and viewing the Runtime Information panel for a selected Runtime., defaults to None
    :type atom_id: str, optional
    """

    def __init__(self, atom_id: str = SENTINEL, **kwargs):
        """AtomPurge

        :param atom_id: The unique ID assigned by the system to the Runtime cloud attachment. The Runtime ID is found in the user interface by navigating to **Manage \> Runtime Management** and viewing the Runtime Information panel for a selected Runtime., defaults to None
        :type atom_id: str, optional
        """
        if atom_id is not SENTINEL:
            self.atom_id = atom_id
        self._kwargs = kwargs




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .edi_delimiter import EdiDelimiter
from .edi_segment_terminator import EdiSegmentTerminator


class X12OptionsAcknowledgementoption(Enum):
    """An enumeration representing different categories.

    :cvar DONOTACKITEM: "donotackitem"
    :vartype DONOTACKITEM: str
    :cvar ACKFUNCITEM: "ackfuncitem"
    :vartype ACKFUNCITEM: str
    :cvar ACKTRANITEM: "acktranitem"
    :vartype ACKTRANITEM: str
    """

    DONOTACKITEM = "donotackitem"
    ACKFUNCITEM = "ackfuncitem"
    ACKTRANITEM = "acktranitem"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, X12OptionsAcknowledgementoption._member_map_.values()
            )
        )


class X12OptionsEnvelopeoption(Enum):
    """An enumeration representing different categories.

    :cvar GROUPALL: "groupall"
    :vartype GROUPALL: str
    :cvar GROUPFG: "groupfg"
    :vartype GROUPFG: str
    :cvar GROUPST: "groupst"
    :vartype GROUPST: str
    """

    GROUPALL = "groupall"
    GROUPFG = "groupfg"
    GROUPST = "groupst"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, X12OptionsEnvelopeoption._member_map_.values())
        )


class X12OptionsOutboundValidationOption(Enum):
    """An enumeration representing different categories.

    :cvar FILTERERROR: "filterError"
    :vartype FILTERERROR: str
    :cvar FAILALL: "failAll"
    :vartype FAILALL: str
    """

    FILTERERROR = "filterError"
    FAILALL = "failAll"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                X12OptionsOutboundValidationOption._member_map_.values(),
            )
        )


@JsonMap(
    {
        "element_delimiter": "elementDelimiter",
        "outbound_interchange_validation": "outboundInterchangeValidation",
        "outbound_validation_option": "outboundValidationOption",
        "reject_duplicate_interchange": "rejectDuplicateInterchange",
        "segment_terminator": "segmentTerminator",
    }
)
class X12Options(BaseModel):
    """X12Options

    :param acknowledgementoption: acknowledgementoption, defaults to None
    :type acknowledgementoption: X12OptionsAcknowledgementoption, optional
    :param element_delimiter: element_delimiter
    :type element_delimiter: EdiDelimiter
    :param envelopeoption: envelopeoption, defaults to None
    :type envelopeoption: X12OptionsEnvelopeoption, optional
    :param filteracknowledgements: filteracknowledgements, defaults to None
    :type filteracknowledgements: bool, optional
    :param outbound_interchange_validation: outbound_interchange_validation, defaults to None
    :type outbound_interchange_validation: bool, optional
    :param outbound_validation_option: outbound_validation_option, defaults to None
    :type outbound_validation_option: X12OptionsOutboundValidationOption, optional
    :param reject_duplicate_interchange: reject_duplicate_interchange, defaults to None
    :type reject_duplicate_interchange: bool, optional
    :param segment_terminator: segment_terminator
    :type segment_terminator: EdiSegmentTerminator
    """

    def __init__(
        self,
        element_delimiter: EdiDelimiter = SENTINEL,
        segment_terminator: EdiSegmentTerminator = SENTINEL,
        acknowledgementoption: X12OptionsAcknowledgementoption = SENTINEL,
        envelopeoption: X12OptionsEnvelopeoption = SENTINEL,
        filteracknowledgements: bool = SENTINEL,
        outbound_interchange_validation: bool = SENTINEL,
        outbound_validation_option: X12OptionsOutboundValidationOption = SENTINEL,
        reject_duplicate_interchange: bool = SENTINEL,
        **kwargs,
    ):
        """X12Options

        :param acknowledgementoption: acknowledgementoption, defaults to None
        :type acknowledgementoption: X12OptionsAcknowledgementoption, optional
        :param element_delimiter: element_delimiter
        :type element_delimiter: EdiDelimiter
        :param envelopeoption: envelopeoption, defaults to None
        :type envelopeoption: X12OptionsEnvelopeoption, optional
        :param filteracknowledgements: filteracknowledgements, defaults to None
        :type filteracknowledgements: bool, optional
        :param outbound_interchange_validation: outbound_interchange_validation, defaults to None
        :type outbound_interchange_validation: bool, optional
        :param outbound_validation_option: outbound_validation_option, defaults to None
        :type outbound_validation_option: X12OptionsOutboundValidationOption, optional
        :param reject_duplicate_interchange: reject_duplicate_interchange, defaults to None
        :type reject_duplicate_interchange: bool, optional
        :param segment_terminator: segment_terminator
        :type segment_terminator: EdiSegmentTerminator
        """
        if acknowledgementoption is not SENTINEL:
            self.acknowledgementoption = self._enum_matching(
                acknowledgementoption,
                X12OptionsAcknowledgementoption.list(),
                "acknowledgementoption",
            )
        if element_delimiter is not SENTINEL:
            self.element_delimiter = self._define_object(element_delimiter, EdiDelimiter)
        if envelopeoption is not SENTINEL:
            self.envelopeoption = self._enum_matching(
                envelopeoption, X12OptionsEnvelopeoption.list(), "envelopeoption"
            )
        if filteracknowledgements is not SENTINEL:
            self.filteracknowledgements = filteracknowledgements
        if outbound_interchange_validation is not SENTINEL:
            self.outbound_interchange_validation = outbound_interchange_validation
        if outbound_validation_option is not SENTINEL:
            self.outbound_validation_option = self._enum_matching(
                outbound_validation_option,
                X12OptionsOutboundValidationOption.list(),
                "outbound_validation_option",
            )
        if reject_duplicate_interchange is not SENTINEL:
            self.reject_duplicate_interchange = reject_duplicate_interchange
        if segment_terminator is not SENTINEL:
            self.segment_terminator = self._define_object(
                segment_terminator, EdiSegmentTerminator
            )
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "batch_size": "batchSize",
        "key_fix_to_length": "keyFixToLength",
        "key_name": "keyName",
    }
)
class MapExtensionsSequentialValue(BaseModel):
    """MapExtensionsSequentialValue

    :param batch_size: batch_size, defaults to None
    :type batch_size: int, optional
    :param key_fix_to_length: key_fix_to_length, defaults to None
    :type key_fix_to_length: int, optional
    :param key_name: key_name, defaults to None
    :type key_name: str, optional
    """

    def __init__(
        self,
        batch_size: int = SENTINEL,
        key_fix_to_length: int = SENTINEL,
        key_name: str = SENTINEL,
        **kwargs
    ):
        """MapExtensionsSequentialValue

        :param batch_size: batch_size, defaults to None
        :type batch_size: int, optional
        :param key_fix_to_length: key_fix_to_length, defaults to None
        :type key_fix_to_length: int, optional
        :param key_name: key_name, defaults to None
        :type key_name: str, optional
        """
        if batch_size is not SENTINEL:
            self.batch_size = batch_size
        if key_fix_to_length is not SENTINEL:
            self.key_fix_to_length = key_fix_to_length
        if key_name is not SENTINEL:
            self.key_name = key_name
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class DelimiterValue(Enum):
    """An enumeration representing different categories.

    :cvar STARDELIMITED: "stardelimited"
    :vartype STARDELIMITED: str
    :cvar COMMADELIMITED: "commadelimited"
    :vartype COMMADELIMITED: str
    :cvar TABDELIMITED: "tabdelimited"
    :vartype TABDELIMITED: str
    :cvar TICKDELIMITED: "tickdelimited"
    :vartype TICKDELIMITED: str
    :cvar BARDELIMITED: "bardelimited"
    :vartype BARDELIMITED: str
    :cvar PLUSDELIMITED: "plusdelimited"
    :vartype PLUSDELIMITED: str
    :cvar COLONDELIMITED: "colondelimited"
    :vartype COLONDELIMITED: str
    :cvar CARATDELIMITED: "caratdelimited"
    :vartype CARATDELIMITED: str
    :cvar AMPERSANDDELIMITED: "ampersanddelimited"
    :vartype AMPERSANDDELIMITED: str
    :cvar BYTECHARACTER: "bytecharacter"
    :vartype BYTECHARACTER: str
    :cvar OTHERCHARACTER: "othercharacter"
    :vartype OTHERCHARACTER: str
    """

    STARDELIMITED = "stardelimited"
    COMMADELIMITED = "commadelimited"
    TABDELIMITED = "tabdelimited"
    TICKDELIMITED = "tickdelimited"
    BARDELIMITED = "bardelimited"
    PLUSDELIMITED = "plusdelimited"
    COLONDELIMITED = "colondelimited"
    CARATDELIMITED = "caratdelimited"
    AMPERSANDDELIMITED = "ampersanddelimited"
    BYTECHARACTER = "bytecharacter"
    OTHERCHARACTER = "othercharacter"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, DelimiterValue._member_map_.values()))


@JsonMap({"delimiter_special": "delimiterSpecial", "delimiter_value": "delimiterValue"})
class EdiDelimiter(BaseModel):
    """EdiDelimiter

    :param delimiter_special: delimiter_special, defaults to None
    :type delimiter_special: str, optional
    :param delimiter_value: delimiter_value, defaults to None
    :type delimiter_value: DelimiterValue, optional
    """

    def __init__(
        self,
        delimiter_special: str = SENTINEL,
        delimiter_value: DelimiterValue = SENTINEL,
        **kwargs
    ):
        """EdiDelimiter

        :param delimiter_special: delimiter_special, defaults to None
        :type delimiter_special: str, optional
        :param delimiter_value: delimiter_value, defaults to None
        :type delimiter_value: DelimiterValue, optional
        """
        if delimiter_special is not SENTINEL:
            self.delimiter_special = delimiter_special
        if delimiter_value is not SENTINEL:
            self.delimiter_value = self._enum_matching(
                delimiter_value, DelimiterValue.list(), "delimiter_value"
            )
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extensions_mapping import MapExtensionsMapping


@JsonMap({"mapping": "Mapping"})
class MapExtensionsExtendedMappings(BaseModel):
    """Represents the field mappings between profiles, functions or both. You can use the following attributes:

    - fromXPath - represents the source profile's field path or the function's output key from which you are mapping.
    - toXPath - represents the destination profile's field path or the function's input key to which you are mapping.
    - toFunction - represents the function ID from which you are mapping.
    - fromFunction - represents the function ID to which you are mapping.

    To properly define each of these attributes, see the section [How to configure ExtendedMappings](/docs/APIs/PlatformAPI/Customizing_profiles_environment_map_extension#how-to-configure-extendedmappings)

    :param mapping: mapping, defaults to None
    :type mapping: List[MapExtensionsMapping], optional
    """

    def __init__(self, mapping: List[MapExtensionsMapping] = SENTINEL, **kwargs):
        """Represents the field mappings between profiles, functions or both. You can use the following attributes:

        - fromXPath - represents the source profile's field path or the function's output key from which you are mapping.
        - toXPath - represents the destination profile's field path or the function's input key to which you are mapping.
        - toFunction - represents the function ID from which you are mapping.
        - fromFunction - represents the function ID to which you are mapping.

        To properly define each of these attributes, see the section [How to configure ExtendedMappings](/docs/APIs/PlatformAPI/Customizing_profiles_environment_map_extension#how-to-configure-extendedmappings)

        :param mapping: mapping, defaults to None
        :type mapping: List[MapExtensionsMapping], optional
        """
        if mapping is not SENTINEL:
            self.mapping = self._define_list(mapping, MapExtensionsMapping)
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class Provider(Enum):
    """An enumeration representing different categories.

    :cvar AWS: "AWS"
    :vartype AWS: str
    :cvar AZURE: "AZURE"
    :vartype AZURE: str
    """

    AWS = "AWS"
    AZURE = "AZURE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Provider._member_map_.values()))


@JsonMap({})
class SecretsManagerRefreshRequest(BaseModel):
    """SecretsManagerRefreshRequest

    :param provider: provider, defaults to None
    :type provider: Provider, optional
    """

    def __init__(self, provider: Provider = SENTINEL, **kwargs):
        """SecretsManagerRefreshRequest

        :param provider: provider, defaults to None
        :type provider: Provider, optional
        """
        if provider is not SENTINEL:
            self.provider = self._enum_matching(provider, Provider.list(), "provider")
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..process import ProcessService
from ...models import (
    Process,
    ProcessBulkResponse,
    ProcessBulkRequest,
    ProcessQueryResponse,
    ProcessQueryConfig,
)


class ProcessServiceAsync(ProcessService):
    """
    Async Wrapper for ProcessServiceAsync
    """

    def get_process(self, id_: str) -> Awaitable[Union[Process, str]]:
        return to_async(super().get_process)(id_)

    def bulk_process(
        self, request_body: ProcessBulkRequest = None
    ) -> Awaitable[Union[ProcessBulkResponse, str]]:
        return to_async(super().bulk_process)(request_body)

    def query_process(
        self, request_body: ProcessQueryConfig = None
    ) -> Awaitable[Union[ProcessQueryResponse, str]]:
        return to_async(super().query_process)(request_body)

    def query_more_process(
        self, request_body: str
    ) -> Awaitable[Union[ProcessQueryResponse, str]]:
        return to_async(super().query_more_process)(request_body)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class MapExtensionsOutput(BaseModel):
    """MapExtensionsOutput

    :param key: key, defaults to None
    :type key: int, optional
    :param name: name, defaults to None
    :type name: str, optional
    """

    def __init__(self, key: int = SENTINEL, name: str = SENTINEL, **kwargs):
        """MapExtensionsOutput

        :param key: key, defaults to None
        :type key: int, optional
        :param name: name, defaults to None
        :type name: str, optional
        """
        if key is not SENTINEL:
            self.key = key
        if name is not SENTINEL:
            self.name = name
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    AuditLog,
    AuditLogBulkRequest,
    AuditLogBulkResponse,
    AuditLogQueryConfig,
    AuditLogQueryResponse,
)


class AuditLogService(BaseService):

    @cast_models
    def get_audit_log(self, id_: str) -> Union[AuditLog, str]:
        """Retrieve audit information for a single audit log entry, like the audit logs action message, the audit log type, action, and modifier. For example, you can use the GET operation to retrieve the environment extensions for a certain date using the document ID.

        :param id_: id_
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AuditLog, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AuditLog/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AuditLog._unmap(response)
        if content == "application/xml":
            return AuditLog._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def bulk_audit_log(
        self, request_body: AuditLogBulkRequest = None
    ) -> Union[AuditLogBulkResponse, str]:
        """To learn more about `bulk`, refer to [Bulk GET operations](#section/Introduction/Bulk-GET-operations).

        :param request_body: The request body., defaults to None
        :type request_body: AuditLogBulkRequest, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AuditLogBulkResponse, str]
        """

        Validator(AuditLogBulkRequest).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AuditLog/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AuditLogBulkResponse._unmap(response)
        if content == "application/xml":
            return AuditLogBulkResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_audit_log(
        self, request_body: AuditLogQueryConfig = None
    ) -> Union[AuditLogQueryResponse, str]:
        """For general information about the structure of QUERY filters, their sample payloads, and how to handle the paged results, refer to [Query filters](#section/Introduction/Query-filters) and [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body., defaults to None
        :type request_body: AuditLogQueryConfig, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AuditLogQueryResponse, str]
        """

        Validator(AuditLogQueryConfig).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AuditLog/query",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AuditLogQueryResponse._unmap(response)
        if content == "application/xml":
            return AuditLogQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_more_audit_log(
        self, request_body: str
    ) -> Union[AuditLogQueryResponse, str]:
        """To learn about using `queryMore`, refer to [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body.
        :type request_body: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AuditLogQueryResponse, str]
        """

        Validator(str).validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/AuditLog/queryMore",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body, "text/plain")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AuditLogQueryResponse._unmap(response)
        if content == "application/xml":
            return AuditLogQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .bulk_id import BulkId


class OrganizationComponentBulkRequestType(Enum):
    """An enumeration representing different categories.

    :cvar GET: "GET"
    :vartype GET: str
    :cvar DELETE: "DELETE"
    :vartype DELETE: str
    :cvar UPDATE: "UPDATE"
    :vartype UPDATE: str
    :cvar CREATE: "CREATE"
    :vartype CREATE: str
    """

    GET = "GET"
    DELETE = "DELETE"
    UPDATE = "UPDATE"
    CREATE = "CREATE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                OrganizationComponentBulkRequestType._member_map_.values(),
            )
        )


@JsonMap({"type_": "type"})
class OrganizationComponentBulkRequest(BaseModel):
    """OrganizationComponentBulkRequest

    :param request: request, defaults to None
    :type request: List[BulkId], optional
    :param type_: type_, defaults to None
    :type type_: OrganizationComponentBulkRequestType, optional
    """

    def __init__(
        self,
        request: List[BulkId] = SENTINEL,
        type_: OrganizationComponentBulkRequestType = SENTINEL,
        **kwargs,
    ):
        """OrganizationComponentBulkRequest

        :param request: request, defaults to None
        :type request: List[BulkId], optional
        :param type_: type_, defaults to None
        :type type_: OrganizationComponentBulkRequestType, optional
        """
        if request is not SENTINEL:
            self.request = self._define_list(request, BulkId)
        if type_ is not SENTINEL:
            self.type_ = self._enum_matching(
                type_, OrganizationComponentBulkRequestType.list(), "type_"
            )
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    CloudAttachmentSecretsConfigurationRequest,
    CloudAttachmentSecretsConfigurationResponse,
)


class CloudAttachmentSecretsConfigurationService(BaseService):

    @cast_models
    def create_cloud_attachment_secrets_configuration(
        self, container_id: str, request_body: CloudAttachmentSecretsConfigurationRequest = None
    ) -> Union[CloudAttachmentSecretsConfigurationResponse, str]:
        """Creates a CloudAttachmentSecretsConfiguration for the specified container.

        :param request_body: The request body., defaults to None
        :type request_body: CloudAttachmentSecretsConfigurationRequest, optional
        :param container_id: The container ID.
        :type container_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[CloudAttachmentSecretsConfigurationResponse, str]
        """

        Validator(CloudAttachmentSecretsConfigurationRequest).is_optional().validate(request_body)
        Validator(str).validate(container_id)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/cloudAttachmentSecretsConfiguration/{{containerId}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("containerId", container_id)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return CloudAttachmentSecretsConfigurationResponse._unmap(response)
        if content == "application/xml":
            return CloudAttachmentSecretsConfigurationResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .scripting_inputs import ScriptingInputs
from .scripting_outputs import ScriptingOutputs


class Language(Enum):
    """An enumeration representing different categories.

    :cvar GROOVY: "GROOVY"
    :vartype GROOVY: str
    :cvar GROOVY2: "GROOVY2"
    :vartype GROOVY2: str
    :cvar JAVASCRIPT: "Javascript"
    :vartype JAVASCRIPT: str
    """

    GROOVY = "GROOVY"
    GROOVY2 = "GROOVY2"
    JAVASCRIPT = "Javascript"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Language._member_map_.values()))


@JsonMap({"inputs": "Inputs", "outputs": "Outputs", "script": "Script"})
class MapExtensionsScripting(BaseModel):
    """MapExtensionsScripting

    :param inputs: inputs
    :type inputs: ScriptingInputs
    :param outputs: outputs
    :type outputs: ScriptingOutputs
    :param script: script
    :type script: str
    :param language: language, defaults to None
    :type language: Language, optional
    """

    def __init__(
        self,
        inputs: ScriptingInputs,
        outputs: ScriptingOutputs,
        script: str,
        language: Language = SENTINEL,
        **kwargs,
    ):
        """MapExtensionsScripting

        :param inputs: inputs
        :type inputs: ScriptingInputs
        :param outputs: outputs
        :type outputs: ScriptingOutputs
        :param script: script
        :type script: str
        :param language: language, defaults to None
        :type language: Language, optional
        """
        self.inputs = self._define_object(inputs, ScriptingInputs)
        self.outputs = self._define_object(outputs, ScriptingOutputs)
        self.script = script
        if language is not SENTINEL:
            self.language = self._enum_matching(language, Language.list(), "language")
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel


@JsonMap(
    {
        "azure_client_id": "azureClientId",
        "azure_client_secret": "azureClientSecret",
        "azure_tenant_id": "azureTenantId",
    }
)
class CloudAttachmentAzureSecretsConfig(BaseModel):
    """CloudAttachmentAzureSecretsConfig

    :param azure_client_id: azure_client_id
    :type azure_client_id: str
    :param azure_client_secret: azure_client_secret
    :type azure_client_secret: str
    :param azure_tenant_id: azure_tenant_id
    :type azure_tenant_id: str
    """

    def __init__(
        self,
        azure_client_id: str,
        azure_client_secret: str,
        azure_tenant_id: str,
        **kwargs,
    ):
        """CloudAttachmentAzureSecretsConfig

        :param azure_client_id: azure_client_id
        :type azure_client_id: str
        :param azure_client_secret: azure_client_secret
        :type azure_client_secret: str
        :param azure_tenant_id: azure_tenant_id
        :type azure_tenant_id: str
        """
        self.azure_client_id = azure_client_id
        self.azure_client_secret = azure_client_secret
        self.azure_tenant_id = azure_tenant_id
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    EnvironmentRole,
    EnvironmentRoleBulkRequest,
    EnvironmentRoleBulkResponse,
    EnvironmentRoleQueryConfig,
    EnvironmentRoleQueryResponse,
)


class EnvironmentRoleService(BaseService):

    @cast_models
    def create_environment_role(
        self, request_body: EnvironmentRole = None
    ) -> Union[EnvironmentRole, str]:
        """Associates a role with an environment. You must have the Runtime Management privilege to perform the CREATE operation.

        :param request_body: The request body., defaults to None
        :type request_body: EnvironmentRole, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[EnvironmentRole, str]
        """

        Validator(EnvironmentRole).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/EnvironmentRole",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return EnvironmentRole._unmap(response)
        if content == "application/xml":
            return EnvironmentRole._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def get_environment_role(self, id_: str) -> Union[EnvironmentRole, str]:
        """Returns a single Environment Role object based on the supplied environment role ID.

        :param id_: The Environment Role object you are attempting to get.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[EnvironmentRole, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/EnvironmentRole/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return EnvironmentRole._unmap(response)
        if content == "application/xml":
            return EnvironmentRole._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def delete_environment_role(self, id_: str) -> None:
        """Removes the association between a role and an environment.

         You must have the Runtime Management privilege to perform the DELETE operation. If you have the Runtime Management privilege, you cannot delete associations between roles and environments.

        :param id_: The Environment Role object you are attempting to delete.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/EnvironmentRole/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("DELETE")
        )

        response, status, _ = self.send_request(serialized_request)

    @cast_models
    def bulk_environment_role(
        self, request_body: EnvironmentRoleBulkRequest = None
    ) -> Union[EnvironmentRoleBulkResponse, str]:
        """To learn more about `bulk`, refer to [Bulk GET operations](#section/Introduction/Bulk-GET-operations).

        :param request_body: The request body., defaults to None
        :type request_body: EnvironmentRoleBulkRequest, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[EnvironmentRoleBulkResponse, str]
        """

        Validator(EnvironmentRoleBulkRequest).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/EnvironmentRole/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return EnvironmentRoleBulkResponse._unmap(response)
        if content == "application/xml":
            return EnvironmentRoleBulkResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_environment_role(
        self, request_body: EnvironmentRoleQueryConfig = None
    ) -> Union[EnvironmentRoleQueryResponse, str]:
        """For general information about the structure of QUERY filters, their sample payloads, and how to handle the paged results, refer to [Query filters](#section/Introduction/Query-filters) and [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body., defaults to None
        :type request_body: EnvironmentRoleQueryConfig, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[EnvironmentRoleQueryResponse, str]
        """

        Validator(EnvironmentRoleQueryConfig).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/EnvironmentRole/query",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return EnvironmentRoleQueryResponse._unmap(response)
        if content == "application/xml":
            return EnvironmentRoleQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_more_environment_role(
        self, request_body: str
    ) -> Union[EnvironmentRoleQueryResponse, str]:
        """To learn about using `queryMore`, refer to [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body.
        :type request_body: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[EnvironmentRoleQueryResponse, str]
        """

        Validator(str).validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/EnvironmentRole/queryMore",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body, "text/plain")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return EnvironmentRoleQueryResponse._unmap(response)
        if content == "application/xml":
            return EnvironmentRoleQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    RuntimeCloud,
    RuntimeCloudBulkRequest,
    RuntimeCloudBulkResponse,
    RuntimeCloudQueryConfig,
    RuntimeCloudQueryResponse,
)


class RuntimeCloudService(BaseService):

    @cast_models
    def create_runtime_cloud(
        self, request_body: RuntimeCloud = None
    ) -> Union[RuntimeCloud, str]:
        """Creates a new RuntimeCloud object.

        :param request_body: The request body., defaults to None
        :type request_body: RuntimeCloud, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeCloud, str]
        """

        Validator(RuntimeCloud).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeCloud._unmap(response)
        if content == "application/xml":
            return RuntimeCloud._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def get_runtime_cloud(self, id_: str) -> Union[RuntimeCloud, str]:
        """Retrieves the properties of the RuntimeCloud having the specified ID.

        :param id_: A unique ID assigned by the system to the RuntimeCloud.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeCloud, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeCloud._unmap(response)
        if content == "application/xml":
            return RuntimeCloud._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def update_runtime_cloud(
        self, id_: str, request_body: RuntimeCloud = None
    ) -> Union[RuntimeCloud, str]:
        """Updates the RuntimeCloud object having the specified ID.

        :param request_body: The request body., defaults to None
        :type request_body: RuntimeCloud, optional
        :param id_: A unique ID assigned by the system to the RuntimeCloud.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeCloud, str]
        """

        Validator(RuntimeCloud).is_optional().validate(request_body)
        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeCloud._unmap(response)
        if content == "application/xml":
            return RuntimeCloud._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def delete_runtime_cloud(self, id_: str) -> None:
        """Deletes the RuntimeCloud object with the specified ID.

        :param id_: A unique ID assigned by the system to the RuntimeCloud.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("DELETE")
        )

        response, status, _ = self.send_request(serialized_request)

    @cast_models
    def bulk_runtime_cloud(
        self, request_body: RuntimeCloudBulkRequest = None
    ) -> Union[RuntimeCloudBulkResponse, str]:
        """To learn more about `bulk`, refer to [Bulk GET operations](#section/Introduction/Bulk-GET-operations).

        :param request_body: The request body., defaults to None
        :type request_body: RuntimeCloudBulkRequest, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeCloudBulkResponse, str]
        """

        Validator(RuntimeCloudBulkRequest).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeCloudBulkResponse._unmap(response)
        if content == "application/xml":
            return RuntimeCloudBulkResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_runtime_cloud(
        self, request_body: RuntimeCloudQueryConfig = None
    ) -> Union[RuntimeCloudQueryResponse, str]:
        """For general information about the structure of QUERY filters, their sample payloads, and how to handle the paged results, refer to [Query filters](#section/Introduction/Query-filters) and [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body., defaults to None
        :type request_body: RuntimeCloudQueryConfig, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeCloudQueryResponse, str]
        """

        Validator(RuntimeCloudQueryConfig).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud/query",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeCloudQueryResponse._unmap(response)
        if content == "application/xml":
            return RuntimeCloudQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_more_runtime_cloud(
        self, request_body: str
    ) -> Union[RuntimeCloudQueryResponse, str]:
        """To learn about using `queryMore`, refer to [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body.
        :type request_body: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeCloudQueryResponse, str]
        """

        Validator(str).validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeCloud/queryMore",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body, "text/plain")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeCloudQueryResponse._unmap(response)
        if content == "application/xml":
            return RuntimeCloudQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .general_settings import GeneralSettings
from .log_settings import LogSettings
from .metric_settings import MetricSettings
from .trace_settings import TraceSettings


@JsonMap(
    {
        "runtime_id": "runtimeId",
        "general_settings": "generalSettings",
        "log_settings": "logSettings",
        "metric_settings": "metricSettings",
        "trace_settings": "traceSettings",
        "should_restart_plugin": "shouldRestartPlugin",
    }
)
class RuntimeObservabilitySettingsRequest(BaseModel):
    """RuntimeObservabilitySettingsRequest

    :param general_settings: general_settings
    :type general_settings: GeneralSettings
    :param log_settings: log_settings
    :type log_settings: LogSettings
    :param metric_settings: metric_settings
    :type metric_settings: MetricSettings
    :param runtime_id: runtime_id
    :type runtime_id: str
    :param trace_settings: trace_settings
    :type trace_settings: TraceSettings
    :param should_restart_plugin: should_restart_plugin, defaults to None
    :type should_restart_plugin: bool, optional
    """

    def __init__(
        self,
        general_settings: GeneralSettings,
        log_settings: LogSettings,
        metric_settings: MetricSettings,
        runtime_id: str,
        trace_settings: TraceSettings,
        should_restart_plugin: bool = SENTINEL,
        **kwargs,
    ):
        """RuntimeObservabilitySettingsRequest

        :param general_settings: general_settings
        :type general_settings: GeneralSettings
        :param log_settings: log_settings
        :type log_settings: LogSettings
        :param metric_settings: metric_settings
        :type metric_settings: MetricSettings
        :param runtime_id: runtime_id
        :type runtime_id: str
        :param trace_settings: trace_settings
        :type trace_settings: TraceSettings
        :param should_restart_plugin: should_restart_plugin, defaults to None
        :type should_restart_plugin: bool, optional
        """
        self.general_settings = self._define_object(
            general_settings, GeneralSettings
        )
        self.log_settings = self._define_object(log_settings, LogSettings)
        self.metric_settings = self._define_object(
            metric_settings, MetricSettings
        )
        self.runtime_id = runtime_id
        self.trace_settings = self._define_object(
            trace_settings, TraceSettings
        )
        if should_restart_plugin is not SENTINEL:
            self.should_restart_plugin = should_restart_plugin
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .rosetta_net_connector_record_simple_expression import (
    RosettaNetConnectorRecordSimpleExpression,
)
from .rosetta_net_connector_record_grouping_expression import (
    RosettaNetConnectorRecordGroupingExpression,
)


class RosettaNetConnectorRecordExpressionGuard(OneOfBaseModel):
    class_list = {
        "RosettaNetConnectorRecordSimpleExpression": RosettaNetConnectorRecordSimpleExpression,
        "RosettaNetConnectorRecordGroupingExpression": RosettaNetConnectorRecordGroupingExpression,
    }


RosettaNetConnectorRecordExpression = Union[
    RosettaNetConnectorRecordSimpleExpression,
    RosettaNetConnectorRecordGroupingExpression,
]




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .organization_component_expression import (
    OrganizationComponentExpression,
    OrganizationComponentExpressionGuard,
)
from .organization_component_simple_expression import (
    OrganizationComponentSimpleExpression,
)
from .organization_component_grouping_expression import (
    OrganizationComponentGroupingExpression,
)


@JsonMap({})
class OrganizationComponentQueryConfigQueryFilter(BaseModel):
    """OrganizationComponentQueryConfigQueryFilter

    :param expression: expression
    :type expression: OrganizationComponentExpression
    """

    def __init__(self, expression: OrganizationComponentExpression, **kwargs):
        """OrganizationComponentQueryConfigQueryFilter

        :param expression: expression
        :type expression: OrganizationComponentExpression
        """
        self.expression = OrganizationComponentExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class OrganizationComponentQueryConfig(BaseModel):
    """OrganizationComponentQueryConfig

    :param query_filter: query_filter
    :type query_filter: OrganizationComponentQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: OrganizationComponentQueryConfigQueryFilter, **kwargs
    ):
        """OrganizationComponentQueryConfig

        :param query_filter: query_filter
        :type query_filter: OrganizationComponentQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, OrganizationComponentQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .shared_web_server_port import SharedWebServerPort


@JsonMap({})
class ListenerPortConfiguration(BaseModel):
    """ListenerPortConfiguration

    :param port: port, defaults to None
    :type port: List[SharedWebServerPort], optional
    """

    def __init__(self, port: List[SharedWebServerPort] = SENTINEL, **kwargs):
        """ListenerPortConfiguration

        :param port: port, defaults to None
        :type port: List[SharedWebServerPort], optional
        """
        if port is not SENTINEL:
            self.port = self._define_list(port, SharedWebServerPort)
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..execution_request import ExecutionRequestService
from ...models import ExecutionRequest


class ExecutionRequestServiceAsync(ExecutionRequestService):
    """
    Async Wrapper for ExecutionRequestServiceAsync
    """

    def create_execution_request(
        self, request_body: ExecutionRequest = None
    ) -> Awaitable[Union[ExecutionRequest, str]]:
        return to_async(super().create_execution_request)(request_body)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"type_": "type"})
class Connector(BaseModel):
    """Connector

    :param name: The user-facing connector label of the connector type, which mimics the connector type names presented on the **Build** tab of the user interface., defaults to None
    :type name: str, optional
    :param type_: The internal and unique identifier for connector type, such as `http`, `ftp`, `greatplains`. The [Component Metadata object](/api/platformapi#tag/ComponentMetadata) refers to this field as *subType*., defaults to None
    :type type_: str, optional
    """

    def __init__(self, name: str = SENTINEL, type_: str = SENTINEL, **kwargs):
        """Connector

        :param name: The user-facing connector label of the connector type, which mimics the connector type names presented on the **Build** tab of the user interface., defaults to None
        :type name: str, optional
        :param type_: The internal and unique identifier for connector type, such as `http`, `ftp`, `greatplains`. The [Component Metadata object](/api/platformapi#tag/ComponentMetadata) refers to this field as *subType*., defaults to None
        :type type_: str, optional
        """
        if name is not SENTINEL:
            self.name = name
        if type_ is not SENTINEL:
            self.type_ = type_
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "default_value": "defaultValue",
        "property_id": "propertyId",
        "property_name": "propertyName",
    }
)
class MapExtensionsDocumentProperty(BaseModel):
    """MapExtensionsDocumentProperty

    :param default_value: default_value, defaults to None
    :type default_value: str, optional
    :param persist: persist, defaults to None
    :type persist: bool, optional
    :param property_id: property_id, defaults to None
    :type property_id: str, optional
    :param property_name: property_name, defaults to None
    :type property_name: str, optional
    """

    def __init__(
        self,
        default_value: str = SENTINEL,
        persist: bool = SENTINEL,
        property_id: str = SENTINEL,
        property_name: str = SENTINEL,
        **kwargs
    ):
        """MapExtensionsDocumentProperty

        :param default_value: default_value, defaults to None
        :type default_value: str, optional
        :param persist: persist, defaults to None
        :type persist: bool, optional
        :param property_id: property_id, defaults to None
        :type property_id: str, optional
        :param property_name: property_name, defaults to None
        :type property_name: str, optional
        """
        if default_value is not SENTINEL:
            self.default_value = default_value
        if persist is not SENTINEL:
            self.persist = persist
        if property_id is not SENTINEL:
            self.property_id = property_id
        if property_name is not SENTINEL:
            self.property_name = property_name
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .comp_diff_config import CompDiffConfig


@JsonMap(
    {
        "comp_diff_config": "CompDiffConfig",
        "component_id": "componentId",
        "source_version": "sourceVersion",
        "target_version": "targetVersion",
    }
)
class ComponentDiffRequest(BaseModel):
    """ComponentDiffRequest

    :param comp_diff_config: comp_diff_config, defaults to None
    :type comp_diff_config: CompDiffConfig, optional
    :param component_id: The ID of the component for which you want to compare versions.
    :type component_id: str
    :param source_version: The source version of the component.
    :type source_version: int
    :param target_version: The target version which you want to compare to the source version.
    :type target_version: int
    """

    def __init__(
        self,
        component_id: str,
        source_version: int,
        target_version: int,
        comp_diff_config: CompDiffConfig = SENTINEL,
        **kwargs,
    ):
        """ComponentDiffRequest

        :param comp_diff_config: comp_diff_config, defaults to None
        :type comp_diff_config: CompDiffConfig, optional
        :param component_id: The ID of the component for which you want to compare versions.
        :type component_id: str
        :param source_version: The source version of the component.
        :type source_version: int
        :param target_version: The target version which you want to compare to the source version.
        :type target_version: int
        """
        if comp_diff_config is not SENTINEL:
            self.comp_diff_config = self._define_object(
                comp_diff_config, CompDiffConfig
            )
        self.component_id = component_id
        self.source_version = source_version
        self.target_version = target_version
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel


@JsonMap(
    {
        "aws_access_key_id": "awsAccessKeyId",
        "aws_region": "awsRegion",
        "aws_secret_access_key": "awsSecretAccessKey",
    }
)
class CloudAttachmentAwsSecretsConfig(BaseModel):
    """CloudAttachmentAwsSecretsConfig

    :param aws_access_key_id: aws_access_key_id
    :type aws_access_key_id: str
    :param aws_region: aws_region
    :type aws_region: str
    :param aws_secret_access_key: aws_secret_access_key
    :type aws_secret_access_key: str
    """

    def __init__(
        self,
        aws_access_key_id: str,
        aws_region: str,
        aws_secret_access_key: str,
        **kwargs,
    ):
        """CloudAttachmentAwsSecretsConfig

        :param aws_access_key_id: aws_access_key_id
        :type aws_access_key_id: str
        :param aws_region: aws_region
        :type aws_region: str
        :param aws_secret_access_key: aws_secret_access_key
        :type aws_secret_access_key: str
        """
        self.aws_access_key_id = aws_access_key_id
        self.aws_region = aws_region
        self.aws_secret_access_key = aws_secret_access_key
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..atom_disk_space import AtomDiskSpaceService
from ...models import AsyncOperationTokenResult, AtomDiskSpaceAsyncResponse


class AtomDiskSpaceServiceAsync(AtomDiskSpaceService):
    """
    Async Wrapper for AtomDiskSpaceServiceAsync
    """

    def async_get_atom_disk_space(
        self, id_: str
    ) -> Awaitable[Union[AsyncOperationTokenResult, str]]:
        return to_async(super().async_get_atom_disk_space)(id_)

    def async_token_atom_disk_space(
        self, token: str
    ) -> Awaitable[Union[AtomDiskSpaceAsyncResponse, str]]:
        return to_async(super().async_token_atom_disk_space)(token)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..connector import ConnectorService
from ...models import (
    Connector,
    ConnectorBulkResponse,
    ConnectorBulkRequest,
    ConnectorQueryResponse,
    ConnectorQueryConfig,
)


class ConnectorServiceAsync(ConnectorService):
    """
    Async Wrapper for ConnectorServiceAsync
    """

    def get_connector(self, connector_type: str) -> Awaitable[Union[Connector, str]]:
        return to_async(super().get_connector)(connector_type)

    def bulk_connector(
        self, request_body: ConnectorBulkRequest = None
    ) -> Awaitable[Union[ConnectorBulkResponse, str]]:
        return to_async(super().bulk_connector)(request_body)

    def query_connector(
        self, request_body: ConnectorQueryConfig = None
    ) -> Awaitable[Union[ConnectorQueryResponse, str]]:
        return to_async(super().query_connector)(request_body)

    def query_more_connector(
        self, request_body: str
    ) -> Awaitable[Union[ConnectorQueryResponse, str]]:
        return to_async(super().query_more_connector)(request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..get_assignable_roles import GetAssignableRolesService
from ...models import Roles


class GetAssignableRolesServiceAsync(GetAssignableRolesService):
    """
    Async Wrapper for GetAssignableRolesServiceAsync
    """

    def get_get_assignable_roles(self) -> Awaitable[Union[Roles, str]]:
        return to_async(super().get_get_assignable_roles)()




from enum import Enum
from typing import get_args, Union
from inspect import isclass
from .one_of_base_model import OneOfBaseModel


def cast_models(func):
    """
    A decorator that allows for the conversion of dictionaries and enum values to model instances.

    :param func: The function to decorate.
    :type func: Callable
    :return: The decorated function.
    :rtype: Callable
    """

    def wrapper(self, *clss, **kwargs):
        cls_types = func.__annotations__
        new_cls_args = []
        new_kwargs = {}

        for input, input_type in zip(clss, cls_types.values()):
            new_cls_args.append(_get_instanced_type(input, input_type))

        for type_name, input in kwargs.items():
            new_kwargs[type_name] = _get_instanced_type(input, cls_types[type_name])

        return func(self, *new_cls_args, **new_kwargs)

    def _get_instanced_type(data, input_type):
        """
        Get instanced type based on the input data and type.

        :param data: The input data.
        :param input_type: The type of the input.
        :return: The instanced type.
        """
        # Instanciate oneOf models
        if _is_one_of_model(input_type):
            class_list = {
                getattr(arg, "__name__", str(arg)): arg for arg in get_args(input_type)
            }
            OneOfBaseModel.class_list = class_list
            return OneOfBaseModel.return_one_of(data)

        # Instanciate enum values
        elif (
            isclass(input_type)
            and issubclass(input_type, Enum)
            and not isinstance(data, input_type)
        ):
            return input_type(data)

        # Instanciate object models
        elif isinstance(data, dict) and input_type is not str:
            return input_type(**data)

        # Instanciate list of object models
        elif isinstance(data, list) and all(isinstance(i, dict) for i in data):
            element_type = get_args(input_type)[0]
            return [element_type(**item) for item in data]

        # Instanciate bytes if input is str
        elif input_type is bytes and isinstance(data, str):
            return data.encode()

        # Pass other types
        else:
            return data

    def _is_one_of_model(cls_type):
        """
        Check if the class type is a oneOf model.

        :param cls_type: The class type to check.
        :return: True if the class type is a oneOf model, False otherwise.
        :rtype: bool
        """
        return hasattr(cls_type, "__origin__") and cls_type.__origin__ is Union

    return wrapper




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .process_schedule_status_simple_expression import (
    ProcessScheduleStatusSimpleExpression,
)
from .process_schedule_status_grouping_expression import (
    ProcessScheduleStatusGroupingExpression,
)


class ProcessScheduleStatusExpressionGuard(OneOfBaseModel):
    class_list = {
        "ProcessScheduleStatusSimpleExpression": ProcessScheduleStatusSimpleExpression,
        "ProcessScheduleStatusGroupingExpression": ProcessScheduleStatusGroupingExpression,
    }


ProcessScheduleStatusExpression = Union[
    ProcessScheduleStatusSimpleExpression, ProcessScheduleStatusGroupingExpression
]




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .release_packaged_component import ReleasePackagedComponent


@JsonMap({"release_packaged_component": "ReleasePackagedComponent"})
class ReleasePackagedComponents(BaseModel):
    """ReleasePackagedComponents

    :param release_packaged_component: release_packaged_component
    :type release_packaged_component: List[ReleasePackagedComponent]
    """

    def __init__(
        self, release_packaged_component: List[ReleasePackagedComponent], **kwargs
    ):
        """ReleasePackagedComponents

        :param release_packaged_component: release_packaged_component
        :type release_packaged_component: List[ReleasePackagedComponent]
        """
        self.release_packaged_component = self._define_list(
            release_packaged_component, ReleasePackagedComponent
        )
        self._kwargs = kwargs




from typing import Any, Set
from .utils import extract_original_data


class Request:
    """
    A simple HTTP request builder class using the requests library.

    Example Usage:
    ```python
    # Create a Request object
    request = Request()

    # Set request parameters
    request.set_url('https://yourendpoint.com/') \
           .set_method('GET') \
           .set_headers({'Content-Type': 'application/json'}) \
           .set_body(None)  # For GET requests, the body should be None

    # Send the HTTP request
    response = request.send()
    ```

    :ivar str url: The URL of the API endpoint.
    :ivar str method: The HTTP method for the request.
    :ivar dict headers: Dictionary of headers to include in the request.
    :ivar Any body: Request body.
    :ivar Set[str] scopes: List of scopes to include in the request.
    :ivar dict errors: Dictionary of HTTP status codes to error models.
    """

    def __init__(self):
        self.url = None
        self.method = None
        self.headers = None
        self.body = None
        self.scopes = None
        self.errors = None

    def set_url(self, url: str) -> "Request":
        """
        Set the URL of the API endpoint.

        :param str url: The URL of the API endpoint.
        :return: The updated Request object.
        :rtype: Request
        """
        self.url = url
        return self

    def set_headers(self, headers: dict) -> "Request":
        """
        Set the headers for the HTTP request.

        :param dict headers: Dictionary of headers to include in the request.
        :return: The updated Request object.
        :rtype: Request
        """
        self.headers = headers
        return self

    def set_method(self, method: str) -> "Request":
        """
        Set the HTTP method for the request.

        :param str method: The HTTP method (e.g., 'GET', 'POST', 'PUT', 'DELETE', etc.).
        :return: The updated Request object.
        :rtype: Request
        """
        self.method = method
        return self

    def set_body(self, body: Any, content_type: str = "application/json") -> "Request":
        """
        Set the request body (e.g., JSON payload).

        :param Any body: Request body.
        :param str content_type: The content type of the request body. Default is "application/json".
        :return: The updated Request object.
        :rtype: Request
        """
        self.body = extract_original_data(body)
        self.headers["Content-Type"] = content_type
        return self

    def set_scopes(self, scopes: Set[str]) -> "Request":
        """
        Set the scopes for the request.

        :param list scopes: List of scopes to include in the request.
        :return: The updated Request object.
        :rtype: Request
        """
        self.scopes = scopes
        return self

    def set_errors(self, errors: dict) -> "Request":
        """
        Set the errors for the request.

        :param dict errors: Dictionary of HTTP status codes to error models.
        :return: The updated Request object.
        :rtype: Request
        """
        self.errors = errors
        return self

    def __str__(self) -> str:
        """
        Return a string representation of the Request object.

        :return: A string representation of the Request object.
        :rtype: str
        """
        return f"Request(url={self.url}, method={self.method}, headers={self.headers}, body={self.body})"




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .encrypted_value import EncryptedValue


@JsonMap({"encrypted_value": "encryptedValue"})
class EncryptedValues(BaseModel):
    """EncryptedValues

    :param encrypted_value: encrypted_value, defaults to None
    :type encrypted_value: List[EncryptedValue], optional
    """

    def __init__(self, encrypted_value: List[EncryptedValue] = SENTINEL, **kwargs):
        """EncryptedValues

        :param encrypted_value: encrypted_value, defaults to None
        :type encrypted_value: List[EncryptedValue], optional
        """
        if encrypted_value is not SENTINEL:
            self.encrypted_value = self._define_list(encrypted_value, EncryptedValue)
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..installer_token import InstallerTokenService
from ...models import InstallerToken


class InstallerTokenServiceAsync(InstallerTokenService):
    """
    Async Wrapper for InstallerTokenServiceAsync
    """

    def create_installer_token(
        self, request_body: InstallerToken = None
    ) -> Awaitable[Union[InstallerToken, str]]:
        return to_async(super().create_installer_token)(request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..java_rollback import JavaRollbackService
from ...models import JavaRollback


class JavaRollbackServiceAsync(JavaRollbackService):
    """
    Async Wrapper for JavaRollbackServiceAsync
    """

    def execute_java_rollback(
        self, id_: str, request_body: JavaRollback = None
    ) -> Awaitable[Union[JavaRollback, str]]:
        return to_async(super().execute_java_rollback)(id_, request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extensions_node import MapExtensionsNode


@JsonMap({"node": "Node", "component_id": "componentId", "type_": "type"})
class MapExtensionsProfile(BaseModel):
    """Represents the fields in a source or destination profile of the given map, and specifies the section of the map in which to extend.

     >**Note:** You cannot add or create new fields in the object's request body. You must add new fields in the user interface of the underlying Map component or from a dynamic reimport. See the Customizing profiles section later in this topic.

    The following SourceProfile attributes define fields in the source profile:

    - componentId - represents the object definition extension ID. A GET request returns this value.
    - name - the user-defined field label(s) found in the source profile.
    - xpath - represents the field location in the source profile hierarchy.

    :param node: node, defaults to None
    :type node: List[MapExtensionsNode], optional
    :param component_id: component_id, defaults to None
    :type component_id: str, optional
    :param type_: type_, defaults to None
    :type type_: str, optional
    """

    def __init__(
        self,
        node: List[MapExtensionsNode] = SENTINEL,
        component_id: str = SENTINEL,
        type_: str = SENTINEL,
        **kwargs,
    ):
        """Represents the fields in a source or destination profile of the given map, and specifies the section of the map in which to extend.

         >**Note:** You cannot add or create new fields in the object's request body. You must add new fields in the user interface of the underlying Map component or from a dynamic reimport. See the Customizing profiles section later in this topic.

        The following SourceProfile attributes define fields in the source profile:

        - componentId - represents the object definition extension ID. A GET request returns this value.
        - name - the user-defined field label(s) found in the source profile.
        - xpath - represents the field location in the source profile hierarchy.

        :param node: node, defaults to None
        :type node: List[MapExtensionsNode], optional
        :param component_id: component_id, defaults to None
        :type component_id: str, optional
        :param type_: type_, defaults to None
        :type type_: str, optional
        """
        if node is not SENTINEL:
            self.node = self._define_list(node, MapExtensionsNode)
        if component_id is not SENTINEL:
            self.component_id = component_id
        if type_ is not SENTINEL:
            self.type_ = type_
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "from_function": "fromFunction",
        "from_x_path": "fromXPath",
        "to_function": "toFunction",
        "to_x_path": "toXPath",
    }
)
class MapExtensionsMapping(BaseModel):
    """MapExtensionsMapping

    :param from_function: from_function, defaults to None
    :type from_function: str, optional
    :param from_x_path: from_x_path, defaults to None
    :type from_x_path: str, optional
    :param to_function: to_function, defaults to None
    :type to_function: str, optional
    :param to_x_path: to_x_path, defaults to None
    :type to_x_path: str, optional
    """

    def __init__(
        self,
        from_function: str = SENTINEL,
        from_x_path: str = SENTINEL,
        to_function: str = SENTINEL,
        to_x_path: str = SENTINEL,
        **kwargs
    ):
        """MapExtensionsMapping

        :param from_function: from_function, defaults to None
        :type from_function: str, optional
        :param from_x_path: from_x_path, defaults to None
        :type from_x_path: str, optional
        :param to_function: to_function, defaults to None
        :type to_function: str, optional
        :param to_x_path: to_x_path, defaults to None
        :type to_x_path: str, optional
        """
        if from_function is not SENTINEL:
            self.from_function = from_function
        if from_x_path is not SENTINEL:
            self.from_x_path = from_x_path
        if to_function is not SENTINEL:
            self.to_function = to_function
        if to_x_path is not SENTINEL:
            self.to_x_path = to_x_path
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..account_cloud_attachment_summary import AccountCloudAttachmentSummaryService
from ...models import (
    AccountCloudAttachmentSummary,
    AccountCloudAttachmentSummaryBulkResponse,
    AccountCloudAttachmentSummaryBulkRequest,
    AccountCloudAttachmentSummaryQueryResponse,
    AccountCloudAttachmentSummaryQueryConfig,
)


class AccountCloudAttachmentSummaryServiceAsync(AccountCloudAttachmentSummaryService):
    """
    Async Wrapper for AccountCloudAttachmentSummaryServiceAsync
    """

    def get_account_cloud_attachment_summary(
        self, id_: str
    ) -> Awaitable[Union[AccountCloudAttachmentSummary, str]]:
        return to_async(super().get_account_cloud_attachment_summary)(id_)

    def bulk_account_cloud_attachment_summary(
        self, request_body: AccountCloudAttachmentSummaryBulkRequest = None
    ) -> Awaitable[Union[AccountCloudAttachmentSummaryBulkResponse, str]]:
        return to_async(super().bulk_account_cloud_attachment_summary)(request_body)

    def query_account_cloud_attachment_summary(
        self, request_body: AccountCloudAttachmentSummaryQueryConfig = None
    ) -> Awaitable[Union[AccountCloudAttachmentSummaryQueryResponse, str]]:
        return to_async(super().query_account_cloud_attachment_summary)(request_body)

    def query_more_account_cloud_attachment_summary(
        self, request_body: str
    ) -> Awaitable[Union[AccountCloudAttachmentSummaryQueryResponse, str]]:
        return to_async(super().query_more_account_cloud_attachment_summary)(request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .role import Role


@JsonMap({"role": "Role"})
class Roles(BaseModel):
    """Roles

    :param role: role, defaults to None
    :type role: List[Role], optional
    """

    def __init__(self, role: List[Role] = SENTINEL, **kwargs):
        """Roles

        :param role: role, defaults to None
        :type role: List[Role], optional
        """
        if role is not SENTINEL:
            self.role = self._define_list(role, Role)
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .environment_role_simple_expression import EnvironmentRoleSimpleExpression
from .environment_role_grouping_expression import EnvironmentRoleGroupingExpression


class EnvironmentRoleExpressionGuard(OneOfBaseModel):
    class_list = {
        "EnvironmentRoleSimpleExpression": EnvironmentRoleSimpleExpression,
        "EnvironmentRoleGroupingExpression": EnvironmentRoleGroupingExpression,
    }


EnvironmentRoleExpression = Union[
    EnvironmentRoleSimpleExpression, EnvironmentRoleGroupingExpression
]




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .as2_connector_record_expression import (
    As2ConnectorRecordExpression,
    As2ConnectorRecordExpressionGuard,
)
from .as2_connector_record_simple_expression import As2ConnectorRecordSimpleExpression
from .as2_connector_record_grouping_expression import (
    As2ConnectorRecordGroupingExpression,
)


@JsonMap({})
class As2ConnectorRecordQueryConfigQueryFilter(BaseModel):
    """As2ConnectorRecordQueryConfigQueryFilter

    :param expression: expression
    :type expression: As2ConnectorRecordExpression
    """

    def __init__(self, expression: As2ConnectorRecordExpression, **kwargs):
        """As2ConnectorRecordQueryConfigQueryFilter

        :param expression: expression
        :type expression: As2ConnectorRecordExpression
        """
        self.expression = As2ConnectorRecordExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class As2ConnectorRecordQueryConfig(BaseModel):
    """As2ConnectorRecordQueryConfig

    :param query_filter: query_filter
    :type query_filter: As2ConnectorRecordQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: As2ConnectorRecordQueryConfigQueryFilter, **kwargs
    ):
        """As2ConnectorRecordQueryConfig

        :param query_filter: query_filter
        :type query_filter: As2ConnectorRecordQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, As2ConnectorRecordQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .x12_connector_record_expression import (
    X12ConnectorRecordExpression,
    X12ConnectorRecordExpressionGuard,
)
from .x12_connector_record_simple_expression import X12ConnectorRecordSimpleExpression
from .x12_connector_record_grouping_expression import (
    X12ConnectorRecordGroupingExpression,
)


@JsonMap({})
class X12ConnectorRecordQueryConfigQueryFilter(BaseModel):
    """X12ConnectorRecordQueryConfigQueryFilter

    :param expression: expression
    :type expression: X12ConnectorRecordExpression
    """

    def __init__(self, expression: X12ConnectorRecordExpression, **kwargs):
        """X12ConnectorRecordQueryConfigQueryFilter

        :param expression: expression
        :type expression: X12ConnectorRecordExpression
        """
        self.expression = X12ConnectorRecordExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class X12ConnectorRecordQueryConfig(BaseModel):
    """X12ConnectorRecordQueryConfig

    :param query_filter: query_filter
    :type query_filter: X12ConnectorRecordQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: X12ConnectorRecordQueryConfigQueryFilter, **kwargs
    ):
        """X12ConnectorRecordQueryConfig

        :param query_filter: query_filter
        :type query_filter: X12ConnectorRecordQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, X12ConnectorRecordQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .oftp2_connector_record_simple_expression import (
    Oftp2ConnectorRecordSimpleExpression,
)
from .oftp2_connector_record_grouping_expression import (
    Oftp2ConnectorRecordGroupingExpression,
)


class Oftp2ConnectorRecordExpressionGuard(OneOfBaseModel):
    class_list = {
        "Oftp2ConnectorRecordSimpleExpression": Oftp2ConnectorRecordSimpleExpression,
        "Oftp2ConnectorRecordGroupingExpression": Oftp2ConnectorRecordGroupingExpression,
    }


Oftp2ConnectorRecordExpression = Union[
    Oftp2ConnectorRecordSimpleExpression, Oftp2ConnectorRecordGroupingExpression
]




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({
    "allow_browsing": "allowBrowsing",
    "allow_deployments": "allowDeployments",
    "allow_test_executions": "allowTestExecutions",
    "created_by": "createdBy",
    "created_date": "createdDate",
    "id_": "id",
    "max_attachments_per_account": "maxAttachmentsPerAccount",
    "modified_by": "modifiedBy",
    "modified_date": "modifiedDate",
})
class RuntimeCloud(BaseModel):
    """RuntimeCloud

    :param classification: classification
    :type classification: str
    :param name: name
    :type name: str
    :param allow_browsing: allow_browsing, defaults to None
    :type allow_browsing: bool, optional
    :param allow_deployments: allow_deployments, defaults to None
    :type allow_deployments: bool, optional
    :param allow_test_executions: allow_test_executions, defaults to None
    :type allow_test_executions: bool, optional
    :param created_by: created_by, defaults to None
    :type created_by: str, optional
    :param created_date: created_date, defaults to None
    :type created_date: str, optional
    :param id_: id_, defaults to None
    :type id_: str, optional
    :param max_attachments_per_account: max_attachments_per_account, defaults to None
    :type max_attachments_per_account: int, optional
    :param modified_by: modified_by, defaults to None
    :type modified_by: str, optional
    :param modified_date: modified_date, defaults to None
    :type modified_date: str, optional
    """

    def __init__(
        self,
        classification: str,
        name: str,
        allow_browsing: bool = SENTINEL,
        allow_deployments: bool = SENTINEL,
        allow_test_executions: bool = SENTINEL,
        created_by: str = SENTINEL,
        created_date: str = SENTINEL,
        id_: str = SENTINEL,
        max_attachments_per_account: int = SENTINEL,
        modified_by: str = SENTINEL,
        modified_date: str = SENTINEL,
        **kwargs,
    ):
        """RuntimeCloud"""
        self.classification = classification
        self.name = name
        if allow_browsing is not SENTINEL:
            self.allow_browsing = allow_browsing
        if allow_deployments is not SENTINEL:
            self.allow_deployments = allow_deployments
        if allow_test_executions is not SENTINEL:
            self.allow_test_executions = allow_test_executions
        if created_by is not SENTINEL:
            self.created_by = created_by
        if created_date is not SENTINEL:
            self.created_date = created_date
        if id_ is not SENTINEL:
            self.id_ = id_
        if max_attachments_per_account is not SENTINEL:
            self.max_attachments_per_account = max_attachments_per_account
        if modified_by is not SENTINEL:
            self.modified_by = modified_by
        if modified_date is not SENTINEL:
            self.modified_date = modified_date
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class AccountGroupIntegrationPackInstallationType(Enum):
    """An enumeration representing different categories.

    :cvar SINGLE: "SINGLE"
    :vartype SINGLE: str
    :cvar MULTI: "MULTI"
    :vartype MULTI: str
    """

    SINGLE = "SINGLE"
    MULTI = "MULTI"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                AccountGroupIntegrationPackInstallationType._member_map_.values(),
            )
        )


@JsonMap(
    {
        "account_group_id": "accountGroupId",
        "id_": "id",
        "installation_type": "installationType",
        "integration_pack_id": "integrationPackId",
        "integration_pack_name": "integrationPackName",
    }
)
class AccountGroupIntegrationPack(BaseModel):
    """AccountGroupIntegrationPack

    :param account_group_id: The ID of the account group., defaults to None
    :type account_group_id: str, optional
    :param id_: A unique ID assigned by the system to the integration pack. This field populates only if you add the integration pack to an account group., defaults to None
    :type id_: str, optional
    :param installation_type: The type of integration pack. Possible values:    - SINGLE — single attachment  - MULTI — multiple attachment, defaults to None
    :type installation_type: AccountGroupIntegrationPackInstallationType, optional
    :param integration_pack_id: A unique ID assigned by the system to the integration pack., defaults to None
    :type integration_pack_id: str, optional
    :param integration_pack_name: The name of the integration pack., defaults to None
    :type integration_pack_name: str, optional
    """

    def __init__(
        self,
        account_group_id: str = SENTINEL,
        id_: str = SENTINEL,
        installation_type: AccountGroupIntegrationPackInstallationType = SENTINEL,
        integration_pack_id: str = SENTINEL,
        integration_pack_name: str = SENTINEL,
        **kwargs
    ):
        """AccountGroupIntegrationPack

        :param account_group_id: The ID of the account group., defaults to None
        :type account_group_id: str, optional
        :param id_: A unique ID assigned by the system to the integration pack. This field populates only if you add the integration pack to an account group., defaults to None
        :type id_: str, optional
        :param installation_type: The type of integration pack. Possible values:    - SINGLE — single attachment  - MULTI — multiple attachment, defaults to None
        :type installation_type: AccountGroupIntegrationPackInstallationType, optional
        :param integration_pack_id: A unique ID assigned by the system to the integration pack., defaults to None
        :type integration_pack_id: str, optional
        :param integration_pack_name: The name of the integration pack., defaults to None
        :type integration_pack_name: str, optional
        """
        if account_group_id is not SENTINEL:
            self.account_group_id = account_group_id
        if id_ is not SENTINEL:
            self.id_ = id_
        if installation_type is not SENTINEL:
            self.installation_type = self._enum_matching(
                installation_type,
                AccountGroupIntegrationPackInstallationType.list(),
                "installation_type",
            )
        if integration_pack_id is not SENTINEL:
            self.integration_pack_id = integration_pack_id
        if integration_pack_name is not SENTINEL:
            self.integration_pack_name = integration_pack_name
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class DeployedPackageListenerStatus(Enum):
    """An enumeration representing different categories.

    :cvar RUNNING: "RUNNING"
    :vartype RUNNING: str
    :cvar PAUSED: "PAUSED"
    :vartype PAUSED: str
    """

    RUNNING = "RUNNING"
    PAUSED = "PAUSED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, DeployedPackageListenerStatus._member_map_.values())
        )


@JsonMap(
    {
        "branch_name": "branchName",
        "component_id": "componentId",
        "component_type": "componentType",
        "component_version": "componentVersion",
        "deployed_by": "deployedBy",
        "deployed_date": "deployedDate",
        "deployment_id": "deploymentId",
        "environment_id": "environmentId",
        "listener_status": "listenerStatus",
        "package_id": "packageId",
        "package_version": "packageVersion",
    }
)
class DeployedPackage(BaseModel):
    """DeployedPackage

    :param active: Identifies if the packaged component is actively deployed., defaults to None
    :type active: bool, optional
    :param branch_name: branch_name, defaults to None
    :type branch_name: str, optional
    :param component_id: The ID of the component. You can use the `componentId` to create and deploy a new packaged component. The **component ID** is available in the **Revision History** dialog, which you can access from the **Build** page in the user interface., defaults to None
    :type component_id: str, optional
    :param component_type: The type of component: \<br /\>-   certificate\<br /\>-   customlibrary\<br /\>-   flowservice\<br /\>-   process\<br /\>-   processroute\<br /\>-   tpgroup\<br /\>-   webservice, defaults to None
    :type component_type: str, optional
    :param component_version: The Revision History number assigned to each saved configuration change made to a component on the **Build** tab. The component version is available in the **Revision History** dialog, which you can access from the **Build** page in the service., defaults to None
    :type component_version: int, optional
    :param deployed_by: The user ID of the user who deployed the packaged component., defaults to None
    :type deployed_by: str, optional
    :param deployed_date: The date and time you deployed the packaged component., defaults to None
    :type deployed_date: str, optional
    :param deployment_id: The ID of the deployment., defaults to None
    :type deployment_id: str, optional
    :param environment_id: The ID of the environment., defaults to None
    :type environment_id: str, optional
    :param listener_status: \(Optional, for packaged listener processes only\) The status of a listener process as RUNNING or PAUSED. If you do not specify `listenerStatus` \(or you specify an invalid value\), the current status remains unchanged. By default, the deployment of listener processes are in a running state.\<br /\>**Important:** This field is only available for the CREATE operation. To retrieve the status of deployed listeners, use the [Listener Status object](/api/platformapi#tag/ListenerStatus)., defaults to None
    :type listener_status: DeployedPackageListenerStatus, optional
    :param message: This tag is returned with the following message only when a successful additional deployment is performed after utilizing all the available connections in the account for CREATE operation:   ``` \<bns:message\>Your packaged components were successfully deployed. You have exceeded the usage count in your current connection licenses by 15. Contact a Boomi representative to purchase a higher connection licenses count.\</bns:message\> ```, defaults to None
    :type message: str, optional
    :param notes: Notes that describe the deployment., defaults to None
    :type notes: str, optional
    :param package_id: The ID of the packaged component. You can use `packageId` to deploy an existing packaged component. The packaged component ID is available from the:\<br /\>-   Packaged Component object\<br /\>-   The **Packaged Component Details** page on the **Deploy** \\> **Packaged Components** page in the user interface., defaults to None
    :type package_id: str, optional
    :param package_version: The user-defined version of the packaged component., defaults to None
    :type package_version: str, optional
    :param version: The version number generated automatically for a deployment., defaults to None
    :type version: int, optional
    """

    def __init__(
        self,
        active: bool = SENTINEL,
        branch_name: str = SENTINEL,
        component_id: str = SENTINEL,
        component_type: str = SENTINEL,
        component_version: int = SENTINEL,
        deployed_by: str = SENTINEL,
        deployed_date: str = SENTINEL,
        deployment_id: str = SENTINEL,
        environment_id: str = SENTINEL,
        listener_status: DeployedPackageListenerStatus = SENTINEL,
        message: str = SENTINEL,
        notes: str = SENTINEL,
        package_id: str = SENTINEL,
        package_version: str = SENTINEL,
        version: int = SENTINEL,
        **kwargs
    ):
        """DeployedPackage

        :param active: Identifies if the packaged component is actively deployed., defaults to None
        :type active: bool, optional
        :param branch_name: branch_name, defaults to None
        :type branch_name: str, optional
        :param component_id: The ID of the component. You can use the `componentId` to create and deploy a new packaged component. The **component ID** is available in the **Revision History** dialog, which you can access from the **Build** page in the user interface., defaults to None
        :type component_id: str, optional
        :param component_type: The type of component: \<br /\>-   certificate\<br /\>-   customlibrary\<br /\>-   flowservice\<br /\>-   process\<br /\>-   processroute\<br /\>-   tpgroup\<br /\>-   webservice, defaults to None
        :type component_type: str, optional
        :param component_version: The Revision History number assigned to each saved configuration change made to a component on the **Build** tab. The component version is available in the **Revision History** dialog, which you can access from the **Build** page in the service., defaults to None
        :type component_version: int, optional
        :param deployed_by: The user ID of the user who deployed the packaged component., defaults to None
        :type deployed_by: str, optional
        :param deployed_date: The date and time you deployed the packaged component., defaults to None
        :type deployed_date: str, optional
        :param deployment_id: The ID of the deployment., defaults to None
        :type deployment_id: str, optional
        :param environment_id: The ID of the environment., defaults to None
        :type environment_id: str, optional
        :param listener_status: \(Optional, for packaged listener processes only\) The status of a listener process as RUNNING or PAUSED. If you do not specify `listenerStatus` \(or you specify an invalid value\), the current status remains unchanged. By default, the deployment of listener processes are in a running state.\<br /\>**Important:** This field is only available for the CREATE operation. To retrieve the status of deployed listeners, use the [Listener Status object](/api/platformapi#tag/ListenerStatus)., defaults to None
        :type listener_status: DeployedPackageListenerStatus, optional
        :param message: This tag is returned with the following message only when a successful additional deployment is performed after utilizing all the available connections in the account for CREATE operation:   ``` \<bns:message\>Your packaged components were successfully deployed. You have exceeded the usage count in your current connection licenses by 15. Contact a Boomi representative to purchase a higher connection licenses count.\</bns:message\> ```, defaults to None
        :type message: str, optional
        :param notes: Notes that describe the deployment., defaults to None
        :type notes: str, optional
        :param package_id: The ID of the packaged component. You can use `packageId` to deploy an existing packaged component. The packaged component ID is available from the:\<br /\>-   Packaged Component object\<br /\>-   The **Packaged Component Details** page on the **Deploy** \\> **Packaged Components** page in the user interface., defaults to None
        :type package_id: str, optional
        :param package_version: The user-defined version of the packaged component., defaults to None
        :type package_version: str, optional
        :param version: The version number generated automatically for a deployment., defaults to None
        :type version: int, optional
        """
        if active is not SENTINEL:
            self.active = active
        if branch_name is not SENTINEL:
            self.branch_name = branch_name
        if component_id is not SENTINEL:
            self.component_id = component_id
        if component_type is not SENTINEL:
            self.component_type = component_type
        if component_version is not SENTINEL:
            self.component_version = component_version
        if deployed_by is not SENTINEL:
            self.deployed_by = deployed_by
        if deployed_date is not SENTINEL:
            self.deployed_date = deployed_date
        if deployment_id is not SENTINEL:
            self.deployment_id = deployment_id
        if environment_id is not SENTINEL:
            self.environment_id = environment_id
        if listener_status is not SENTINEL:
            self.listener_status = self._enum_matching(
                listener_status, DeployedPackageListenerStatus.list(), "listener_status"
            )
        if message is not SENTINEL:
            self.message = message
        if notes is not SENTINEL:
            self.notes = notes
        if package_id is not SENTINEL:
            self.package_id = package_id
        if package_version is not SENTINEL:
            self.package_version = package_version
        if version is not SENTINEL:
            self.version = version
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "id_": "id",
        "type_": "type",
        "encrypted_value_set": "encryptedValueSet",
    }
)
class ObservabilityAuthenticationFields(BaseModel):
    """ObservabilityAuthenticationFields

    :param id_: id_
    :type id_: str
    :param type_: type_
    :type type_: str
    :param value: value
    :type value: str
    :param encrypted_value_set: encrypted_value_set, defaults to None
    :type encrypted_value_set: bool, optional
    """

    def __init__(
        self,
        id_: str,
        type_: str,
        value: str,
        encrypted_value_set: bool = SENTINEL,
        **kwargs,
    ):
        """ObservabilityAuthenticationFields

        :param id_: id_
        :type id_: str
        :param type_: type_
        :type type_: str
        :param value: value
        :type value: str
        :param encrypted_value_set: encrypted_value_set, defaults to None
        :type encrypted_value_set: bool, optional
        """
        self.id_ = id_
        self.type_ = type_
        self.value = value
        if encrypted_value_set is not SENTINEL:
            self.encrypted_value_set = encrypted_value_set
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .branch_simple_expression import BranchSimpleExpression
from .branch_grouping_expression import BranchGroupingExpression


class BranchExpressionGuard(OneOfBaseModel):
    class_list = {
        "BranchSimpleExpression": BranchSimpleExpression,
        "BranchGroupingExpression": BranchGroupingExpression,
    }


BranchExpression = Union[BranchSimpleExpression, BranchGroupingExpression]




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .processing_group_document_standard_route import (
    ProcessingGroupDocumentStandardRoute,
)


@JsonMap({"standard_route": "StandardRoute", "process_id": "processId"})
class ProcessingGroupDocumentBasedRouting(BaseModel):
    """ProcessingGroupDocumentBasedRouting

    :param standard_route: standard_route, defaults to None
    :type standard_route: List[ProcessingGroupDocumentStandardRoute], optional
    :param process_id: process_id, defaults to None
    :type process_id: str, optional
    """

    def __init__(
        self,
        standard_route: List[ProcessingGroupDocumentStandardRoute] = SENTINEL,
        process_id: str = SENTINEL,
        **kwargs,
    ):
        """ProcessingGroupDocumentBasedRouting

        :param standard_route: standard_route, defaults to None
        :type standard_route: List[ProcessingGroupDocumentStandardRoute], optional
        :param process_id: process_id, defaults to None
        :type process_id: str, optional
        """
        if standard_route is not SENTINEL:
            self.standard_route = self._define_list(
                standard_route, ProcessingGroupDocumentStandardRoute
            )
        if process_id is not SENTINEL:
            self.process_id = process_id
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel


@JsonMap(
    {
        "address1": "address1",
        "address2": "address2",
        "city": "city",
        "contact_name": "contactName",
        "contact_url": "contactUrl",
        "country": "country",
        "email": "email",
        "fax": "fax",
        "phone": "phone",
        "postalcode": "postalcode",
        "state": "state",
    }
)
class OrganizationContactInfo(BaseModel):
    """OrganizationContactInfo

    :param address1: First line of the street address of the organization.
    :type address1: str
    :param address2: Second line of the street address of the organization.
    :type address2: str
    :param city: Location of the city for the organization.
    :type city: str
    :param contact_name: Name of the contact for the organization.
    :type contact_name: str
    :param contact_url: Contact URL for the organization.
    :type contact_url: str
    :param country: Location of the country for the organization.
    :type country: str
    :param email: Email address of the organization.
    :type email: str
    :param fax: Fax number for the organization.
    :type fax: str
    :param phone: Phone number for the organization.
    :type phone: str
    :param postalcode: Postal code, such as a Zip Code.
    :type postalcode: str
    :param state: Location of the state or province for the organization.
    :type state: str
    """

    def __init__(
        self,
        address1: str,
        address2: str,
        city: str,
        contact_name: str,
        contact_url: str,
        country: str,
        email: str,
        fax: str,
        phone: str,
        postalcode: str,
        state: str,
        **kwargs
    ):
        """OrganizationContactInfo

        :param address1: First line of the street address of the organization.
        :type address1: str
        :param address2: Second line of the street address of the organization.
        :type address2: str
        :param city: Location of the city for the organization.
        :type city: str
        :param contact_name: Name of the contact for the organization.
        :type contact_name: str
        :param contact_url: Contact URL for the organization.
        :type contact_url: str
        :param country: Location of the country for the organization.
        :type country: str
        :param email: Email address of the organization.
        :type email: str
        :param fax: Fax number for the organization.
        :type fax: str
        :param phone: Phone number for the organization.
        :type phone: str
        :param postalcode: Postal code, such as a Zip Code.
        :type postalcode: str
        :param state: Location of the state or province for the organization.
        :type state: str
        """
        self.address1 = address1
        self.address2 = address2
        self.city = city
        self.contact_name = contact_name
        self.contact_url = contact_url
        self.country = country
        self.email = email
        self.fax = fax
        self.phone = phone
        self.postalcode = postalcode
        self.state = state
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..packaged_component_manifest import PackagedComponentManifestService
from ...models import (
    PackagedComponentManifest,
    PackagedComponentManifestBulkResponse,
    PackagedComponentManifestBulkRequest,
)


class PackagedComponentManifestServiceAsync(PackagedComponentManifestService):
    """
    Async Wrapper for PackagedComponentManifestServiceAsync
    """

    def get_packaged_component_manifest(
        self, package_id: str
    ) -> Awaitable[Union[PackagedComponentManifest, str]]:
        return to_async(super().get_packaged_component_manifest)(package_id)

    def bulk_packaged_component_manifest(
        self, request_body: PackagedComponentManifestBulkRequest = None
    ) -> Awaitable[Union[PackagedComponentManifestBulkResponse, str]]:
        return to_async(super().bulk_packaged_component_manifest)(request_body)




from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class Oftp2ConnectorRecordSimpleExpressionOperator(Enum):
    """An enumeration representing different categories.

    :cvar EQUALS: "EQUALS"
    :vartype EQUALS: str
    :cvar STARTSWITH: "STARTS_WITH"
    :vartype STARTSWITH: str
    :cvar BETWEEN: "BETWEEN"
    :vartype BETWEEN: str
    :cvar GREATERTHAN: "GREATER_THAN"
    :vartype GREATERTHAN: str
    :cvar GREATERTHANOREQUAL: "GREATER_THAN_OR_EQUAL"
    :vartype GREATERTHANOREQUAL: str
    :cvar LESSTHAN: "LESS_THAN"
    :vartype LESSTHAN: str
    :cvar LESSTHANOREQUAL: "LESS_THAN_OR_EQUAL"
    :vartype LESSTHANOREQUAL: str
    """

    EQUALS = "EQUALS"
    STARTSWITH = "STARTS_WITH"
    BETWEEN = "BETWEEN"
    GREATERTHAN = "GREATER_THAN"
    GREATERTHANOREQUAL = "GREATER_THAN_OR_EQUAL"
    LESSTHAN = "LESS_THAN"
    LESSTHANOREQUAL = "LESS_THAN_OR_EQUAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                Oftp2ConnectorRecordSimpleExpressionOperator._member_map_.values(),
            )
        )


class Oftp2ConnectorRecordSimpleExpressionProperty(Enum):
    """An enumeration representing different categories.

    :cvar SFIDDSN: "sfiddsn"
    :vartype SFIDDSN: str
    :cvar SFIDDATE: "sfiddate"
    :vartype SFIDDATE: str
    :cvar SFIDTIME: "sfidtime"
    :vartype SFIDTIME: str
    :cvar SFIDDEST: "sfiddest"
    :vartype SFIDDEST: str
    :cvar INITIATORSSIDCODE: "initiator_ssidcode"
    :vartype INITIATORSSIDCODE: str
    :cvar RESPONDERSSIDCODE: "responder_ssidcode"
    :vartype RESPONDERSSIDCODE: str
    :cvar SFIDORIG: "sfidorig"
    :vartype SFIDORIG: str
    :cvar SFIDSEC: "sfidsec"
    :vartype SFIDSEC: str
    :cvar SFIDCOMP: "sfidcomp"
    :vartype SFIDCOMP: str
    :cvar SFIDCIPH: "sfidciph"
    :vartype SFIDCIPH: str
    :cvar SFIDDESC: "sfiddesc"
    :vartype SFIDDESC: str
    :cvar SFIDSIGN: "sfidsign"
    :vartype SFIDSIGN: str
    :cvar SFIDOSIZ: "sfidosiz"
    :vartype SFIDOSIZ: str
    :cvar SFIDENV: "sfidenv"
    :vartype SFIDENV: str
    :cvar STATUS: "status"
    :vartype STATUS: str
    :cvar ACCOUNT: "account"
    :vartype ACCOUNT: str
    :cvar EXECUTIONID: "executionId"
    :vartype EXECUTIONID: str
    :cvar ATOMID: "atomId"
    :vartype ATOMID: str
    :cvar DATEPROCESSED: "dateProcessed"
    :vartype DATEPROCESSED: str
    :cvar ID: "id"
    :vartype ID: str
    :cvar ACTIONTYPE: "actionType"
    :vartype ACTIONTYPE: str
    :cvar CONNECTORTYPE: "connectorType"
    :vartype CONNECTORTYPE: str
    :cvar CONNECTORNAME: "connectorName"
    :vartype CONNECTORNAME: str
    :cvar OPERATIONNAME: "operationName"
    :vartype OPERATIONNAME: str
    :cvar DOCUMENTINDEX: "documentIndex"
    :vartype DOCUMENTINDEX: str
    :cvar SUCCESSFUL: "successful"
    :vartype SUCCESSFUL: str
    :cvar SIZE: "size"
    :vartype SIZE: str
    :cvar CUSTOMFIELDS: "customFields"
    :vartype CUSTOMFIELDS: str
    :cvar NAREAS: "nareas"
    :vartype NAREAS: str
    :cvar NAREAST: "nareast"
    :vartype NAREAST: str
    """

    SFIDDSN = "sfiddsn"
    SFIDDATE = "sfiddate"
    SFIDTIME = "sfidtime"
    SFIDDEST = "sfiddest"
    INITIATORSSIDCODE = "initiator_ssidcode"
    RESPONDERSSIDCODE = "responder_ssidcode"
    SFIDORIG = "sfidorig"
    SFIDSEC = "sfidsec"
    SFIDCOMP = "sfidcomp"
    SFIDCIPH = "sfidciph"
    SFIDDESC = "sfiddesc"
    SFIDSIGN = "sfidsign"
    SFIDOSIZ = "sfidosiz"
    SFIDENV = "sfidenv"
    STATUS = "status"
    ACCOUNT = "account"
    EXECUTIONID = "executionId"
    ATOMID = "atomId"
    DATEPROCESSED = "dateProcessed"
    ID = "id"
    ACTIONTYPE = "actionType"
    CONNECTORTYPE = "connectorType"
    CONNECTORNAME = "connectorName"
    OPERATIONNAME = "operationName"
    DOCUMENTINDEX = "documentIndex"
    SUCCESSFUL = "successful"
    SIZE = "size"
    CUSTOMFIELDS = "customFields"
    NAREAS = "nareas"
    NAREAST = "nareast"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                Oftp2ConnectorRecordSimpleExpressionProperty._member_map_.values(),
            )
        )


@JsonMap({})
class Oftp2ConnectorRecordSimpleExpression(BaseModel):
    """Oftp2ConnectorRecordSimpleExpression

    :param argument: argument, defaults to None
    :type argument: List[str], optional
    :param operator: operator
    :type operator: Oftp2ConnectorRecordSimpleExpressionOperator
    :param property: property
    :type property: Oftp2ConnectorRecordSimpleExpressionProperty
    """

    def __init__(
        self,
        operator: Oftp2ConnectorRecordSimpleExpressionOperator,
        property: Oftp2ConnectorRecordSimpleExpressionProperty,
        argument: List[str] = SENTINEL,
        **kwargs
    ):
        """Oftp2ConnectorRecordSimpleExpression

        :param argument: argument, defaults to None
        :type argument: List[str], optional
        :param operator: operator
        :type operator: Oftp2ConnectorRecordSimpleExpressionOperator
        :param property: property
        :type property: Oftp2ConnectorRecordSimpleExpressionProperty
        """
        if argument is not SENTINEL:
            self.argument = argument
        self.operator = self._enum_matching(
            operator, Oftp2ConnectorRecordSimpleExpressionOperator.list(), "operator"
        )
        self.property = self._enum_matching(
            property, Oftp2ConnectorRecordSimpleExpressionProperty.list(), "property"
        )
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .atom_security_policy_argument_type import AtomSecurityPolicyArgumentType


@JsonMap({"privilege_type": "privilegeType"})
class AtomSecurityPolicy(BaseModel):
    """AtomSecurityPolicy

    :param arguments: arguments, defaults to None
    :type arguments: List[AtomSecurityPolicyArgumentType], optional
    :param privilege_type: A valid Java runtime permission.
    :type privilege_type: str
    """

    def __init__(
        self,
        privilege_type: str,
        arguments: List[AtomSecurityPolicyArgumentType] = SENTINEL,
        **kwargs,
    ):
        """AtomSecurityPolicy

        :param arguments: arguments, defaults to None
        :type arguments: List[AtomSecurityPolicyArgumentType], optional
        :param privilege_type: A valid Java runtime permission.
        :type privilege_type: str
        """
        if arguments is not SENTINEL:
            self.arguments = self._define_list(
                arguments, AtomSecurityPolicyArgumentType
            )
        self.privilege_type = privilege_type
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "integration_pack_id": "integrationPackId",
        "integration_pack_instance_id": "integrationPackInstanceId",
    }
)
class ProcessIntegrationPackInfo(BaseModel):
    """ProcessIntegrationPackInfo

    :param integration_pack_id: If the process is in an installed integration pack, this is the unique ID assigned by the system to the integration pack., defaults to None
    :type integration_pack_id: str, optional
    :param integration_pack_instance_id: If the process is in an installed integration pack, this is the unique ID assigned by the system to the installed instance of the integration pack., defaults to None
    :type integration_pack_instance_id: str, optional
    """

    def __init__(
        self,
        integration_pack_id: str = SENTINEL,
        integration_pack_instance_id: str = SENTINEL,
        **kwargs
    ):
        """ProcessIntegrationPackInfo

        :param integration_pack_id: If the process is in an installed integration pack, this is the unique ID assigned by the system to the integration pack., defaults to None
        :type integration_pack_id: str, optional
        :param integration_pack_instance_id: If the process is in an installed integration pack, this is the unique ID assigned by the system to the installed instance of the integration pack., defaults to None
        :type integration_pack_instance_id: str, optional
        """
        if integration_pack_id is not SENTINEL:
            self.integration_pack_id = integration_pack_id
        if integration_pack_instance_id is not SENTINEL:
            self.integration_pack_instance_id = integration_pack_instance_id
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class Action(Enum):
    """An enumeration representing different categories.

    :cvar RESTART: "restart"
    :vartype RESTART: str
    :cvar RESTARTALL: "restart_all"
    :vartype RESTARTALL: str
    :cvar PAUSE: "pause"
    :vartype PAUSE: str
    :cvar PAUSEALL: "pause_all"
    :vartype PAUSEALL: str
    :cvar RESUME: "resume"
    :vartype RESUME: str
    :cvar RESUMEALL: "resume_all"
    :vartype RESUMEALL: str
    """

    RESTART = "restart"
    RESTARTALL = "restart_all"
    PAUSE = "pause"
    PAUSEALL = "pause_all"
    RESUME = "resume"
    RESUMEALL = "resume_all"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Action._member_map_.values()))


@JsonMap({"container_id": "containerId", "listener_id": "listenerId"})
class ChangeListenerStatusRequest(BaseModel):
    """ChangeListenerStatusRequest

    :param action: The action to be performed., defaults to None
    :type action: Action, optional
    :param container_id: The ID of the Runtime, Runtime cluster, or Runtime cloud to which you deploy the listener or listeners., defaults to None
    :type container_id: str, optional
    :param listener_id: The ID of a single listener process whose status you want to change. To change the status of all listeners, omit this parameter.   \>**Note:** You can obtain the ID for a listener process by using a QUERY operation on the Process object., defaults to None
    :type listener_id: str, optional
    """

    def __init__(
        self,
        action: Action = SENTINEL,
        container_id: str = SENTINEL,
        listener_id: str = SENTINEL,
        **kwargs
    ):
        """ChangeListenerStatusRequest

        :param action: The action to be performed., defaults to None
        :type action: Action, optional
        :param container_id: The ID of the Runtime, Runtime cluster, or Runtime cloud to which you deploy the listener or listeners., defaults to None
        :type container_id: str, optional
        :param listener_id: The ID of a single listener process whose status you want to change. To change the status of all listeners, omit this parameter.   \>**Note:** You can obtain the ID for a listener process by using a QUERY operation on the Process object., defaults to None
        :type listener_id: str, optional
        """
        if action is not SENTINEL:
            self.action = self._enum_matching(action, Action.list(), "action")
        if container_id is not SENTINEL:
            self.container_id = container_id
        if listener_id is not SENTINEL:
            self.listener_id = listener_id
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .custom_fields import CustomFields


@JsonMap(
    {
        "ack_report": "ackReport",
        "ack_requested": "ackRequested",
        "ack_status": "ackStatus",
        "action_type": "actionType",
        "atom_id": "atomId",
        "connector_name": "connectorName",
        "connector_type": "connectorType",
        "controlling_agency": "controllingAgency",
        "custom_fields": "customFields",
        "date_processed": "dateProcessed",
        "document_index": "documentIndex",
        "error_message": "errorMessage",
        "execution_id": "executionId",
        "id_": "id",
        "interchange_control_reference": "interchangeControlReference",
        "interchange_date": "interchangeDate",
        "interchange_time": "interchangeTime",
        "message_reference_number": "messageReferenceNumber",
        "message_type": "messageType",
        "operation_name": "operationName",
        "outbound_validation_report": "outboundValidationReport",
        "outbound_validation_status": "outboundValidationStatus",
        "receiver_id": "receiverID",
        "sender_id": "senderID",
    }
)
class EdifactConnectorRecord(BaseModel):
    """EdifactConnectorRecord

    :param account: The ID of the account from which you ran this record.
    :type account: str
    :param ack_report: The acknowledgment report., defaults to None
    :type ack_report: str, optional
    :param ack_requested: The UNB09, the Acknowledgement Request field value, determines whether the sending trading partner requests a CONTRL message as functional acknowledgment. A value of 1 indicates there is an acknowledgment request. An empty value means there is no acknowledgment request., defaults to None
    :type ack_requested: str, optional
    :param ack_status: The acknowledgment status — either Accepted, Received, or Rejected., defaults to None
    :type ack_status: str, optional
    :param action_type: The type of action with which this record corresponds — Send for an outbound interchange, Get for an inbound interchange using the Disk, FTP, or SFTP communication method, or Listen for an inbound interchange using the AS2 or HTTP communication method.
    :type action_type: str
    :param atom_id: The ID of the Atom that processed this record.
    :type atom_id: str
    :param connector_name: The value is Trading Partner for an EDIFACT trading partner Send operation, or Start for an EDIFACT trading partner Listen operation.
    :type connector_name: str
    :param connector_type: edifact is the connector type for any record.
    :type connector_type: str
    :param controlling_agency: The controlling agency for the message type., defaults to None
    :type controlling_agency: str, optional
    :param custom_fields: custom_fields
    :type custom_fields: CustomFields
    :param date_processed: The processing date and time of this record. The format is yyyy-MM-dd'T'HH:mm:ss'Z', for example, 2018-08-08T15:32:00Z.
    :type date_processed: str
    :param document_index: The numerical index of this record in the run., defaults to None
    :type document_index: int, optional
    :param error_message: Any error message associated with this record.
    :type error_message: str
    :param execution_id: The ID of the run.
    :type execution_id: str
    :param id_: The ID of this record.
    :type id_: str
    :param interchange_control_reference: The number that uniquely identifies the interchange., defaults to None
    :type interchange_control_reference: str, optional
    :param interchange_date: The date of preparation. The format is *yyMMdd*., defaults to None
    :type interchange_date: str, optional
    :param interchange_time: The time of preparation. The format is *HHmm*., defaults to None
    :type interchange_time: str, optional
    :param message_reference_number: The unique message reference assigned by the sender., defaults to None
    :type message_reference_number: str, optional
    :param message_type: The code identifying the type of message., defaults to None
    :type message_type: str, optional
    :param operation_name: The name of the operation component that processed the record.
    :type operation_name: str
    :param outbound_validation_report: The outbound validation report. This report contains descriptions of errors present in the outbound interchange. If the outbound validation option is not selected in the sending trading partner, the value is N/A. An inbound interchange omits this field., defaults to None
    :type outbound_validation_report: str, optional
    :param outbound_validation_status: The outbound validation status — either Success, Error - Interchange, Error - Message, or N/A. For an outbound interchange for which the outbound validation option is not selected in the sending trading partner, the value is *N/A*. An inbound interchange omits this field., defaults to None
    :type outbound_validation_status: str, optional
    :param receiver_id: For an inbound interchange, the UNB03, Interchange Receiver ID, field value, which identifies the receiver., defaults to None
    :type receiver_id: str, optional
    :param release: The message type release number., defaults to None
    :type release: str, optional
    :param sender_id: For an outbound interchange, the UNB02, Interchange Sender ID, field value, which identifies the sender., defaults to None
    :type sender_id: str, optional
    :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
    :type size: int, optional
    :param successful: Whether the record is a success or an error., defaults to None
    :type successful: bool, optional
    :param version: The message type version number., defaults to None
    :type version: str, optional
    """

    def __init__(
        self,
        account: str,
        action_type: str,
        atom_id: str,
        connector_name: str,
        connector_type: str,
        custom_fields: CustomFields,
        date_processed: str,
        error_message: str,
        execution_id: str,
        id_: str,
        operation_name: str,
        ack_report: str = SENTINEL,
        ack_requested: str = SENTINEL,
        ack_status: str = SENTINEL,
        controlling_agency: str = SENTINEL,
        document_index: int = SENTINEL,
        interchange_control_reference: str = SENTINEL,
        interchange_date: str = SENTINEL,
        interchange_time: str = SENTINEL,
        message_reference_number: str = SENTINEL,
        message_type: str = SENTINEL,
        outbound_validation_report: str = SENTINEL,
        outbound_validation_status: str = SENTINEL,
        receiver_id: str = SENTINEL,
        release: str = SENTINEL,
        sender_id: str = SENTINEL,
        size: int = SENTINEL,
        successful: bool = SENTINEL,
        version: str = SENTINEL,
        **kwargs,
    ):
        """EdifactConnectorRecord

        :param account: The ID of the account from which you ran this record.
        :type account: str
        :param ack_report: The acknowledgment report., defaults to None
        :type ack_report: str, optional
        :param ack_requested: The UNB09, the Acknowledgement Request field value, determines whether the sending trading partner requests a CONTRL message as functional acknowledgment. A value of 1 indicates there is an acknowledgment request. An empty value means there is no acknowledgment request., defaults to None
        :type ack_requested: str, optional
        :param ack_status: The acknowledgment status — either Accepted, Received, or Rejected., defaults to None
        :type ack_status: str, optional
        :param action_type: The type of action with which this record corresponds — Send for an outbound interchange, Get for an inbound interchange using the Disk, FTP, or SFTP communication method, or Listen for an inbound interchange using the AS2 or HTTP communication method.
        :type action_type: str
        :param atom_id: The ID of the Atom that processed this record.
        :type atom_id: str
        :param connector_name: The value is Trading Partner for an EDIFACT trading partner Send operation, or Start for an EDIFACT trading partner Listen operation.
        :type connector_name: str
        :param connector_type: edifact is the connector type for any record.
        :type connector_type: str
        :param controlling_agency: The controlling agency for the message type., defaults to None
        :type controlling_agency: str, optional
        :param custom_fields: custom_fields
        :type custom_fields: CustomFields
        :param date_processed: The processing date and time of this record. The format is yyyy-MM-dd'T'HH:mm:ss'Z', for example, 2018-08-08T15:32:00Z.
        :type date_processed: str
        :param document_index: The numerical index of this record in the run., defaults to None
        :type document_index: int, optional
        :param error_message: Any error message associated with this record.
        :type error_message: str
        :param execution_id: The ID of the run.
        :type execution_id: str
        :param id_: The ID of this record.
        :type id_: str
        :param interchange_control_reference: The number that uniquely identifies the interchange., defaults to None
        :type interchange_control_reference: str, optional
        :param interchange_date: The date of preparation. The format is *yyMMdd*., defaults to None
        :type interchange_date: str, optional
        :param interchange_time: The time of preparation. The format is *HHmm*., defaults to None
        :type interchange_time: str, optional
        :param message_reference_number: The unique message reference assigned by the sender., defaults to None
        :type message_reference_number: str, optional
        :param message_type: The code identifying the type of message., defaults to None
        :type message_type: str, optional
        :param operation_name: The name of the operation component that processed the record.
        :type operation_name: str
        :param outbound_validation_report: The outbound validation report. This report contains descriptions of errors present in the outbound interchange. If the outbound validation option is not selected in the sending trading partner, the value is N/A. An inbound interchange omits this field., defaults to None
        :type outbound_validation_report: str, optional
        :param outbound_validation_status: The outbound validation status — either Success, Error - Interchange, Error - Message, or N/A. For an outbound interchange for which the outbound validation option is not selected in the sending trading partner, the value is *N/A*. An inbound interchange omits this field., defaults to None
        :type outbound_validation_status: str, optional
        :param receiver_id: For an inbound interchange, the UNB03, Interchange Receiver ID, field value, which identifies the receiver., defaults to None
        :type receiver_id: str, optional
        :param release: The message type release number., defaults to None
        :type release: str, optional
        :param sender_id: For an outbound interchange, the UNB02, Interchange Sender ID, field value, which identifies the sender., defaults to None
        :type sender_id: str, optional
        :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
        :type size: int, optional
        :param successful: Whether the record is a success or an error., defaults to None
        :type successful: bool, optional
        :param version: The message type version number., defaults to None
        :type version: str, optional
        """
        self.account = account
        if ack_report is not SENTINEL:
            self.ack_report = ack_report
        if ack_requested is not SENTINEL:
            self.ack_requested = ack_requested
        if ack_status is not SENTINEL:
            self.ack_status = ack_status
        self.action_type = action_type
        self.atom_id = atom_id
        self.connector_name = connector_name
        self.connector_type = connector_type
        if controlling_agency is not SENTINEL:
            self.controlling_agency = controlling_agency
        self.custom_fields = self._define_object(custom_fields, CustomFields)
        self.date_processed = date_processed
        if document_index is not SENTINEL:
            self.document_index = document_index
        self.error_message = error_message
        self.execution_id = execution_id
        self.id_ = id_
        if interchange_control_reference is not SENTINEL:
            self.interchange_control_reference = interchange_control_reference
        if interchange_date is not SENTINEL:
            self.interchange_date = interchange_date
        if interchange_time is not SENTINEL:
            self.interchange_time = interchange_time
        if message_reference_number is not SENTINEL:
            self.message_reference_number = message_reference_number
        if message_type is not SENTINEL:
            self.message_type = message_type
        self.operation_name = operation_name
        if outbound_validation_report is not SENTINEL:
            self.outbound_validation_report = outbound_validation_report
        if outbound_validation_status is not SENTINEL:
            self.outbound_validation_status = outbound_validation_status
        if receiver_id is not SENTINEL:
            self.receiver_id = receiver_id
        if release is not SENTINEL:
            self.release = release
        if sender_id is not SENTINEL:
            self.sender_id = sender_id
        if size is not SENTINEL:
            self.size = size
        if successful is not SENTINEL:
            self.successful = successful
        if version is not SENTINEL:
            self.version = version
        self._kwargs = kwargs




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .http_get_options import HttpGetOptions
from .http_listen_options import HttpListenOptions
from .http_send_options import HttpSendOptions
from .http_settings import HttpSettings
from .shared_communication_channel import SharedCommunicationChannel


class HttpCommunicationOptionsCommunicationSetting(Enum):
    """An enumeration representing different categories.

    :cvar DEFAULT: "default"
    :vartype DEFAULT: str
    :cvar CUSTOM: "custom"
    :vartype CUSTOM: str
    :cvar COMPONENT: "component"
    :vartype COMPONENT: str
    """

    DEFAULT = "default"
    CUSTOM = "custom"
    COMPONENT = "component"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                HttpCommunicationOptionsCommunicationSetting._member_map_.values(),
            )
        )


@JsonMap(
    {
        "communication_setting": "CommunicationSetting",
        "http_get_options": "HTTPGetOptions",
        "http_listen_options": "HTTPListenOptions",
        "http_send_options": "HTTPSendOptions",
        "http_settings": "HTTPSettings",
        "shared_communication_channel": "SharedCommunicationChannel",
    }
)
class HttpCommunicationOptions(BaseModel):
    """HttpCommunicationOptions

    :param communication_setting: communication_setting, defaults to None
    :type communication_setting: HttpCommunicationOptionsCommunicationSetting, optional
    :param http_get_options: http_get_options, defaults to None
    :type http_get_options: HttpGetOptions, optional
    :param http_listen_options: http_listen_options, defaults to None
    :type http_listen_options: HttpListenOptions, optional
    :param http_send_options: http_send_options, defaults to None
    :type http_send_options: HttpSendOptions, optional
    :param http_settings: http_settings, defaults to None
    :type http_settings: HttpSettings, optional
    :param shared_communication_channel: shared_communication_channel, defaults to None
    :type shared_communication_channel: SharedCommunicationChannel, optional
    """

    def __init__(
        self,
        communication_setting: HttpCommunicationOptionsCommunicationSetting = SENTINEL,
        http_get_options: HttpGetOptions = SENTINEL,
        http_listen_options: HttpListenOptions = SENTINEL,
        http_send_options: HttpSendOptions = SENTINEL,
        http_settings: HttpSettings = SENTINEL,
        shared_communication_channel: SharedCommunicationChannel = SENTINEL,
        **kwargs,
    ):
        """HttpCommunicationOptions

        :param communication_setting: communication_setting, defaults to None
        :type communication_setting: HttpCommunicationOptionsCommunicationSetting, optional
        :param http_get_options: http_get_options, defaults to None
        :type http_get_options: HttpGetOptions, optional
        :param http_listen_options: http_listen_options, defaults to None
        :type http_listen_options: HttpListenOptions, optional
        :param http_send_options: http_send_options, defaults to None
        :type http_send_options: HttpSendOptions, optional
        :param http_settings: http_settings, defaults to None
        :type http_settings: HttpSettings, optional
        :param shared_communication_channel: shared_communication_channel, defaults to None
        :type shared_communication_channel: SharedCommunicationChannel, optional
        """
        if communication_setting is not SENTINEL:
            self.communication_setting = self._enum_matching(
                communication_setting,
                HttpCommunicationOptionsCommunicationSetting.list(),
                "communication_setting",
            )
        if http_get_options is not SENTINEL:
            self.http_get_options = self._define_object(
                http_get_options, HttpGetOptions
            )
        if http_listen_options is not SENTINEL:
            self.http_listen_options = self._define_object(
                http_listen_options, HttpListenOptions
            )
        if http_send_options is not SENTINEL:
            self.http_send_options = self._define_object(
                http_send_options, HttpSendOptions
            )
        if http_settings is not SENTINEL:
            self.http_settings = self._define_object(http_settings, HttpSettings)
        if shared_communication_channel is not SENTINEL:
            self.shared_communication_channel = self._define_object(
                shared_communication_channel, SharedCommunicationChannel
            )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .odette_unb_control_info import OdetteUnbControlInfo
from .odette_unh_control_info import OdetteUnhControlInfo


@JsonMap(
    {
        "odette_unb_control_info": "OdetteUNBControlInfo",
        "odette_unh_control_info": "OdetteUNHControlInfo",
    }
)
class OdetteControlInfo(BaseModel):
    """OdetteControlInfo

    :param odette_unb_control_info: odette_unb_control_info, defaults to None
    :type odette_unb_control_info: OdetteUnbControlInfo, optional
    :param odette_unh_control_info: odette_unh_control_info, defaults to None
    :type odette_unh_control_info: OdetteUnhControlInfo, optional
    """

    def __init__(
        self,
        odette_unb_control_info: OdetteUnbControlInfo = SENTINEL,
        odette_unh_control_info: OdetteUnhControlInfo = SENTINEL,
        **kwargs,
    ):
        """OdetteControlInfo

        :param odette_unb_control_info: odette_unb_control_info, defaults to None
        :type odette_unb_control_info: OdetteUnbControlInfo, optional
        :param odette_unh_control_info: odette_unh_control_info, defaults to None
        :type odette_unh_control_info: OdetteUnhControlInfo, optional
        """
        if odette_unb_control_info is not SENTINEL:
            self.odette_unb_control_info = self._define_object(
                odette_unb_control_info, OdetteUnbControlInfo
            )
        if odette_unh_control_info is not SENTINEL:
            self.odette_unh_control_info = self._define_object(
                odette_unh_control_info, OdetteUnhControlInfo
            )
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class AttachmentOption(Enum):
    """An enumeration representing different categories.

    :cvar BATCH: "BATCH"
    :vartype BATCH: str
    :cvar DOCUMENTCACHE: "DOCUMENT_CACHE"
    :vartype DOCUMENTCACHE: str
    """

    BATCH = "BATCH"
    DOCUMENTCACHE = "DOCUMENT_CACHE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, AttachmentOption._member_map_.values()))


class DataContentType(Enum):
    """An enumeration representing different categories.

    :cvar TEXTPLAIN: "textplain"
    :vartype TEXTPLAIN: str
    :cvar BINARY: "binary"
    :vartype BINARY: str
    :cvar EDIFACT: "edifact"
    :vartype EDIFACT: str
    :cvar EDIX12: "edix12"
    :vartype EDIX12: str
    :cvar APPLICATIONXML: "applicationxml"
    :vartype APPLICATIONXML: str
    :cvar TEXTXML: "textxml"
    :vartype TEXTXML: str
    """

    TEXTPLAIN = "textplain"
    BINARY = "binary"
    EDIFACT = "edifact"
    EDIX12 = "edix12"
    APPLICATIONXML = "applicationxml"
    TEXTXML = "textxml"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, DataContentType._member_map_.values()))


class As2MessageOptionsEncryptionAlgorithm(Enum):
    """An enumeration representing different categories.

    :cvar NA: "na"
    :vartype NA: str
    :cvar TRIPLEDES: "tripledes"
    :vartype TRIPLEDES: str
    :cvar DES: "des"
    :vartype DES: str
    :cvar RC2_128: "rc2-128"
    :vartype RC2_128: str
    :cvar RC2_64: "rc2-64"
    :vartype RC2_64: str
    :cvar RC2_40: "rc2-40"
    :vartype RC2_40: str
    :cvar AES128: "aes-128"
    :vartype AES128: str
    :cvar AES192: "aes-192"
    :vartype AES192: str
    :cvar AES256: "aes-256"
    :vartype AES256: str
    """

    NA = "na"
    TRIPLEDES = "tripledes"
    DES = "des"
    RC2_128 = "rc2-128"
    RC2_64 = "rc2-64"
    RC2_40 = "rc2-40"
    AES128 = "aes-128"
    AES192 = "aes-192"
    AES256 = "aes-256"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                As2MessageOptionsEncryptionAlgorithm._member_map_.values(),
            )
        )


class SigningDigestAlg(Enum):
    """An enumeration representing different categories.

    :cvar SHA1: "SHA1"
    :vartype SHA1: str
    :cvar SHA224: "SHA224"
    :vartype SHA224: str
    :cvar SHA256: "SHA256"
    :vartype SHA256: str
    :cvar SHA384: "SHA384"
    :vartype SHA384: str
    :cvar SHA512: "SHA512"
    :vartype SHA512: str
    """

    SHA1 = "SHA1"
    SHA224 = "SHA224"
    SHA256 = "SHA256"
    SHA384 = "SHA384"
    SHA512 = "SHA512"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SigningDigestAlg._member_map_.values()))


@JsonMap(
    {
        "attachment_cache": "attachmentCache",
        "attachment_option": "attachmentOption",
        "data_content_type": "dataContentType",
        "encryption_algorithm": "encryptionAlgorithm",
        "max_document_count": "maxDocumentCount",
        "multiple_attachments": "multipleAttachments",
        "signing_digest_alg": "signingDigestAlg",
    }
)
class As2MessageOptions(BaseModel):
    """As2MessageOptions

    :param attachment_cache: attachment_cache, defaults to None
    :type attachment_cache: str, optional
    :param attachment_option: attachment_option, defaults to None
    :type attachment_option: AttachmentOption, optional
    :param compressed: compressed, defaults to None
    :type compressed: bool, optional
    :param data_content_type: data_content_type, defaults to None
    :type data_content_type: DataContentType, optional
    :param encrypted: encrypted, defaults to None
    :type encrypted: bool, optional
    :param encryption_algorithm: encryption_algorithm, defaults to None
    :type encryption_algorithm: As2MessageOptionsEncryptionAlgorithm, optional
    :param max_document_count: max_document_count, defaults to None
    :type max_document_count: int, optional
    :param multiple_attachments: multiple_attachments, defaults to None
    :type multiple_attachments: bool, optional
    :param signed: signed, defaults to None
    :type signed: bool, optional
    :param signing_digest_alg: signing_digest_alg, defaults to None
    :type signing_digest_alg: SigningDigestAlg, optional
    :param subject: subject, defaults to None
    :type subject: str, optional
    """

    def __init__(
        self,
        attachment_cache: str = SENTINEL,
        attachment_option: AttachmentOption = SENTINEL,
        compressed: bool = SENTINEL,
        data_content_type: DataContentType = SENTINEL,
        encrypted: bool = SENTINEL,
        encryption_algorithm: As2MessageOptionsEncryptionAlgorithm = SENTINEL,
        max_document_count: int = SENTINEL,
        multiple_attachments: bool = SENTINEL,
        signed: bool = SENTINEL,
        signing_digest_alg: SigningDigestAlg = SENTINEL,
        subject: str = SENTINEL,
        **kwargs
    ):
        """As2MessageOptions

        :param attachment_cache: attachment_cache, defaults to None
        :type attachment_cache: str, optional
        :param attachment_option: attachment_option, defaults to None
        :type attachment_option: AttachmentOption, optional
        :param compressed: compressed, defaults to None
        :type compressed: bool, optional
        :param data_content_type: data_content_type, defaults to None
        :type data_content_type: DataContentType, optional
        :param encrypted: encrypted, defaults to None
        :type encrypted: bool, optional
        :param encryption_algorithm: encryption_algorithm, defaults to None
        :type encryption_algorithm: As2MessageOptionsEncryptionAlgorithm, optional
        :param max_document_count: max_document_count, defaults to None
        :type max_document_count: int, optional
        :param multiple_attachments: multiple_attachments, defaults to None
        :type multiple_attachments: bool, optional
        :param signed: signed, defaults to None
        :type signed: bool, optional
        :param signing_digest_alg: signing_digest_alg, defaults to None
        :type signing_digest_alg: SigningDigestAlg, optional
        :param subject: subject, defaults to None
        :type subject: str, optional
        """
        if attachment_cache is not SENTINEL:
            self.attachment_cache = attachment_cache
        if attachment_option is not SENTINEL:
            self.attachment_option = self._enum_matching(
                attachment_option, AttachmentOption.list(), "attachment_option"
            )
        if compressed is not SENTINEL:
            self.compressed = compressed
        if data_content_type is not SENTINEL:
            self.data_content_type = self._enum_matching(
                data_content_type, DataContentType.list(), "data_content_type"
            )
        if encrypted is not SENTINEL:
            self.encrypted = encrypted
        if encryption_algorithm is not SENTINEL:
            self.encryption_algorithm = self._enum_matching(
                encryption_algorithm,
                As2MessageOptionsEncryptionAlgorithm.list(),
                "encryption_algorithm",
            )
        if max_document_count is not SENTINEL:
            self.max_document_count = max_document_count
        if multiple_attachments is not SENTINEL:
            self.multiple_attachments = multiple_attachments
        if signed is not SENTINEL:
            self.signed = signed
        if signing_digest_alg is not SENTINEL:
            self.signing_digest_alg = self._enum_matching(
                signing_digest_alg, SigningDigestAlg.list(), "signing_digest_alg"
            )
        if subject is not SENTINEL:
            self.subject = subject
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .schedule_retry import ScheduleRetry
from .schedule import Schedule


@JsonMap(
    {
        "retry": "Retry",
        "schedule": "Schedule",
        "atom_id": "atomId",
        "id_": "id",
        "process_id": "processId",
    }
)
class ProcessSchedules(BaseModel):
    """ProcessSchedules

    :param retry: retry, defaults to None
    :type retry: ScheduleRetry, optional
    :param schedule: schedule, defaults to None
    :type schedule: List[Schedule], optional
    :param atom_id: A unique ID assigned by the system to the Runtime., defaults to None
    :type atom_id: str, optional
    :param id_: The object’s conceptual ID, which is synthesized from the process and Runtime IDs., defaults to None
    :type id_: str, optional
    :param process_id: A unique ID assigned by the system to the process. Must not be a listener process., defaults to None
    :type process_id: str, optional
    """

    def __init__(
        self,
        retry: ScheduleRetry = SENTINEL,
        schedule: List[Schedule] = SENTINEL,
        atom_id: str = SENTINEL,
        id_: str = SENTINEL,
        process_id: str = SENTINEL,
        **kwargs,
    ):
        """ProcessSchedules

        :param retry: retry, defaults to None
        :type retry: ScheduleRetry, optional
        :param schedule: schedule, defaults to None
        :type schedule: List[Schedule], optional
        :param atom_id: A unique ID assigned by the system to the Runtime., defaults to None
        :type atom_id: str, optional
        :param id_: The object’s conceptual ID, which is synthesized from the process and Runtime IDs., defaults to None
        :type id_: str, optional
        :param process_id: A unique ID assigned by the system to the process. Must not be a listener process., defaults to None
        :type process_id: str, optional
        """
        if retry is not SENTINEL:
            self.retry = self._define_object(retry, ScheduleRetry)
        if schedule is not SENTINEL:
            self.schedule = self._define_list(schedule, Schedule)
        if atom_id is not SENTINEL:
            self.atom_id = atom_id
        if id_ is not SENTINEL:
            self.id_ = id_
        if process_id is not SENTINEL:
            self.process_id = process_id
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"atom_id": "atomId", "log_date": "logDate"})
class AtomAs2Artifacts(BaseModel):
    """AtomAs2Artifacts

    :param atom_id: The ID of the Runtime., defaults to None
    :type atom_id: str, optional
    :param log_date: The date of the logged events., defaults to None
    :type log_date: str, optional
    """

    def __init__(self, atom_id: str = SENTINEL, log_date: str = SENTINEL, **kwargs):
        """AtomAs2Artifacts

        :param atom_id: The ID of the Runtime., defaults to None
        :type atom_id: str, optional
        :param log_date: The date of the logged events., defaults to None
        :type log_date: str, optional
        """
        if atom_id is not SENTINEL:
            self.atom_id = atom_id
        if log_date is not SENTINEL:
            self.log_date = log_date
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class SecretsManagerType(Enum):
    """An enumeration representing different categories.

    :cvar AWS: "AWS"
    :vartype AWS: str
    :cvar AZURE: "AZURE"
    :vartype AZURE: str
    :cvar GCP: "GCP"
    :vartype GCP: str
    """

    AWS = "AWS"
    AZURE = "AZURE"
    GCP = "GCP"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SecretsManagerType._member_map_.values())
        )


@JsonMap(
    {
        "secret_reference": "secretReference",
        "secrets_manager_type": "secretsManagerType",
        "uses_remote_secrets_manager": "usesRemoteSecretsManager",
    }
)
class CloudManagedSecretConfig(BaseModel):
    """CloudManagedSecretConfig

    :param secret_reference: secret_reference, defaults to None
    :type secret_reference: str, optional
    :param secrets_manager_type: secrets_manager_type, defaults to None
    :type secrets_manager_type: SecretsManagerType, optional
    :param uses_remote_secrets_manager: uses_remote_secrets_manager, defaults to None
    :type uses_remote_secrets_manager: bool, optional
    """

    def __init__(
        self,
        secret_reference: str = SENTINEL,
        secrets_manager_type: SecretsManagerType = SENTINEL,
        uses_remote_secrets_manager: bool = SENTINEL,
        **kwargs,
    ):
        """CloudManagedSecretConfig

        :param secret_reference: secret_reference, defaults to None
        :type secret_reference: str, optional
        :param secrets_manager_type: secrets_manager_type, defaults to None
        :type secrets_manager_type: SecretsManagerType, optional
        :param uses_remote_secrets_manager: uses_remote_secrets_manager, defaults to None
        :type uses_remote_secrets_manager: bool, optional
        """
        if secret_reference is not SENTINEL:
            self.secret_reference = secret_reference
        if secrets_manager_type is not SENTINEL:
            self.secrets_manager_type = self._enum_matching(
                secrets_manager_type,
                SecretsManagerType.list(),
                "secrets_manager_type",
            )
        if uses_remote_secrets_manager is not SENTINEL:
            self.uses_remote_secrets_manager = uses_remote_secrets_manager
        self._kwargs = kwargs
